@@ -130,10 +130,15 @@ public class Activator extends AbstractUIPlugin {
 	public static final String IMG_HEADER_SHOWHIDE_XP_CLASSIC	= "IMG_HEADER_SHOWHIDE_XP_CLASSIC";
 
 	public static final String IMG_COMP_SETTINGS		= "IMG_COMP_SETTINGS";
+	public static final String IMG_COMP_SS_NONE			= "IMG_COMP_SS_NONE";
+	public static final String IMG_COMP_SS_2X2			= "IMG_COMP_SS_2X2";
+	public static final String IMG_COMP_SS_3X3			= "IMG_COMP_SS_3X3";
+	public static final String IMG_COMP_SS_4X4			= "IMG_COMP_SS_4X4";
 	public static final String IMG_COMP_MBLUR			= "IMG_COMP_MBLUR";
 	public static final String IMG_COMP_FBLEND			= "IMG_COMP_FBLEND";
 	public static final String IMG_COMP_SHY				= "IMG_COMP_SHY";
 
+	public static final String IMG_LIGHT	= "IMG_LIGHT";
 	public static final String IMG_CAMERA	= "IMG_CAMERA";
 	public static final String IMG_TEXT		= "IMG_TEXT";
 
@@ -142,10 +147,14 @@ public class Activator extends AbstractUIPlugin {
 
 	public static final String IMG_SWITCH_UNSHY				= "IMG_SWITCH_UNSHY";
 	public static final String IMG_SWITCH_SHY				= "IMG_SWITCH_SHY";
+	public static final String IMG_SWITCH_QUALITY_DRAFT		= "IMG_SWITCH_QUALITY_DRAFT";
+	public static final String IMG_SWITCH_QUALITY_NORMAL	= "IMG_SWITCH_QUALITY_NORMAL";
+	public static final String IMG_SWITCH_QUALITY_BEST		= "IMG_SWITCH_QUALITY_BEST";
 	public static final String IMG_SWITCH_EFFECT			= "IMG_SWITCH_EFFECT";
 	public static final String IMG_SWITCH_CTCR				= "IMG_SWITCH_CTCR";
 	public static final String IMG_SWITCH_FBLEND			= "IMG_SWITCH_FBLEND";
-	public static final String IMG_SWITCH_MBLUR				= "IMG_SWITCH_MBLUR";
+	public static final String IMG_SWITCH_MBLUR_TRANSFORM	= "IMG_SWITCH_MBLUR_TRANSFORM";
+	public static final String IMG_SWITCH_MBLUR_FULL		= "IMG_SWITCH_MBLUR_FULL";
 	public static final String IMG_SWITCH_3D				= "IMG_SWITCH_3D";
 	public static final String IMG_SWITCH_LINK				= "IMG_SWITCH_LINK";
 	public static final String IMG_SWITCH_TINY_2D_MANIP		= "IMG_SWITCH_TINY_2D_MANIP";
@@ -194,10 +203,15 @@ public class Activator extends AbstractUIPlugin {
 		}
 
 		registerImage(reg, IMG_COMP_SETTINGS, "comp_settings.png");
+		registerImage(reg, IMG_COMP_SS_NONE, "comp_ss_none.png");
+		registerImage(reg, IMG_COMP_SS_2X2, "comp_ss_2x2.png");
+		registerImage(reg, IMG_COMP_SS_3X3, "comp_ss_3x3.png");
+		registerImage(reg, IMG_COMP_SS_4X4, "comp_ss_4x4.png");
 		registerImage(reg, IMG_COMP_MBLUR, "comp_mblur.png");
 		registerImage(reg, IMG_COMP_FBLEND, "comp_fblend.png");
 		registerImage(reg, IMG_COMP_SHY, "comp_shy.png");
 
+		registerImage(reg, IMG_LIGHT, "light.png");
 		registerImage(reg, IMG_CAMERA, "camera.png");
 		registerImage(reg, IMG_TEXT, "text.png");
 
@@ -207,8 +221,12 @@ public class Activator extends AbstractUIPlugin {
 		registerImage(reg, IMG_SWITCH_UNSHY, "switch_unshy.png");
 		registerImage(reg, IMG_SWITCH_SHY, "switch_shy.png");
 		registerImage(reg, IMG_SWITCH_CTCR, "switch_ctcr.png");
+		registerImage(reg, IMG_SWITCH_QUALITY_DRAFT, "switch_quality_draft.png");
+		registerImage(reg, IMG_SWITCH_QUALITY_NORMAL, "switch_quality_normal.png");
+		registerImage(reg, IMG_SWITCH_QUALITY_BEST, "switch_quality_best.png");
 		registerImage(reg, IMG_SWITCH_FBLEND, "switch_fblend.png");
-		registerImage(reg, IMG_SWITCH_MBLUR, "switch_mblur.png");
+		registerImage(reg, IMG_SWITCH_MBLUR_TRANSFORM, "switch_mblur_transform.png");
+		registerImage(reg, IMG_SWITCH_MBLUR_FULL, "switch_mblur_full.png");
 		registerImage(reg, IMG_SWITCH_EFFECT, "switch_effect.png");
 		registerImage(reg, IMG_SWITCH_3D, "switch_3d.png");
 		registerImage(reg, IMG_SWITCH_LINK, "switch_link.png");
