@@ -125,6 +125,8 @@ public class ApplicationActionBarAdvisor extends ActionBarAdvisor {
 
 	private IWorkbenchAction selectAllAction;
 
+	private RetargetAction newLightLayerAction;
+
 	private RetargetAction newCameraLayerAction;
 
 	private RetargetAction newNullLayerAction;
@@ -240,6 +242,10 @@ public class ApplicationActionBarAdvisor extends ActionBarAdvisor {
 		selectAllAction = ActionFactory.SELECT_ALL.create(window);
 		register(selectAllAction);
 
+		newLightLayerAction = new RetargetAction(CommandIds.NEW_LIGHT_LAYER, "ライト");
+		register(newLightLayerAction);
+		window.getPartService().addPartListener(newLightLayerAction);
+
 		newCameraLayerAction = new RetargetAction(CommandIds.NEW_CAMERA_LAYER, "カメラ");
 		register(newCameraLayerAction);
 		window.getPartService().addPartListener(newCameraLayerAction);
@@ -332,7 +338,7 @@ public class ApplicationActionBarAdvisor extends ActionBarAdvisor {
 	protected void fillMenuBar(IMenuManager menuBar) {
 		MenuManager fileMenu = new MenuManager("&File", IWorkbenchActionConstants.M_FILE);
 		MenuManager fileNewMenu = new MenuManager("新規");
-		MenuManager inputMenu = new MenuManager("読み込み");
+		MenuManager inputMenu = new MenuManager("読み込み", "ch.kuramo.javie.menu.input");
 		MenuManager outputMenu = new MenuManager("書き出し");
 		MenuManager editMenu = new MenuManager("&Edit", IWorkbenchActionConstants.M_EDIT);
 		MenuManager layerMenu = new MenuManager("&Layer" /* TODO idが必要？ */);
@@ -374,6 +380,8 @@ public class ApplicationActionBarAdvisor extends ActionBarAdvisor {
 		// File/Input
 		inputMenu.add(newFileItemsAction);
 		inputMenu.add(newImageSequenceAction);
+		inputMenu.add(new Separator());
+		inputMenu.add(new GroupMarker(IWorkbenchActionConstants.MB_ADDITIONS));
 
 		// File/Output
 		if (aviOutputAction != null) outputMenu.add(aviOutputAction);
@@ -397,6 +405,7 @@ public class ApplicationActionBarAdvisor extends ActionBarAdvisor {
 		layerMenu.add(splitLayersAction);
 
 		// Layer/New
+		layerNewMenu.add(newLightLayerAction);
 		layerNewMenu.add(newCameraLayerAction);
 		layerNewMenu.add(newNullLayerAction);
 		layerNewMenu.add(newTextLayerAction);
