@@ -397,7 +397,7 @@ public class VideoCanvas extends Thread implements GLEventListener {
 			_glu = GLU.createGLU(gl);
 			_glut = new GLUT();
 
-			gl.glEnable(GL2.GL_TEXTURE_RECTANGLE);
+			gl.glEnable(GL2.GL_TEXTURE_2D);
 			gl.glColor4f(1, 1, 1, 1);
 
 			// 背景を黒以外にする場合はアルファブレンドを有効にし、blendFuncを次のように設定する。
@@ -456,16 +456,16 @@ public class VideoCanvas extends Thread implements GLEventListener {
 			_glu.gluOrtho2D(0, w, h, 0);
 
 
-			gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, vb.getTexture());
+			gl.glBindTexture(GL2.GL_TEXTURE_2D, vb.getTexture());
 
 			gl.glBegin(GL2.GL_QUADS);
 			gl.glTexCoord2f(0, 0); gl.glVertex2f(0, 0);
-			gl.glTexCoord2f(w, 0); gl.glVertex2f(w, 0);
-			gl.glTexCoord2f(w, h); gl.glVertex2f(w, h);
-			gl.glTexCoord2f(0, h); gl.glVertex2f(0, h);
+			gl.glTexCoord2f(1, 0); gl.glVertex2f(w, 0);
+			gl.glTexCoord2f(1, 1); gl.glVertex2f(w, h);
+			gl.glTexCoord2f(0, 1); gl.glVertex2f(0, h);
 			gl.glEnd();
 
-			gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, 0);
+			gl.glBindTexture(GL2.GL_TEXTURE_2D, 0);
 
 			if (_showInfo) {
 				gl.glPushAttrib(GL2.GL_ENABLE_BIT | GL2.GL_CURRENT_BIT | GL2.GL_COLOR_BUFFER_BIT);
@@ -848,16 +848,16 @@ public class VideoCanvas extends Thread implements GLEventListener {
 		// (GMA X4500で確認) 
 
 		gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
-				GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_RECTANGLE, vb.getTexture(), 0);
+				GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_2D, vb.getTexture(), 0);
 
 		gl.glFinish();
 
 		gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
-				GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_RECTANGLE, 0, 0);
+				GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_2D, 0, 0);
 	}
 
 	private void setTexParametersForDisplay(IVideoBuffer vb, Resolution resolution, GL2 gl) {
-		gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, vb.getTexture());
+		gl.glBindTexture(GL2.GL_TEXTURE_2D, vb.getTexture());
 
 		// フル解像度のときは、拡大したときにテクスチャの補間が効かないようにする。
 		// フル解像度でないときは補間を有効にするが、補間によってエッジ部分が
@@ -866,17 +866,17 @@ public class VideoCanvas extends Thread implements GLEventListener {
 		if (Resolution.FULL.equals(resolution)) {
 			// GL_TEXTURE_MAG_FILTER だけ設定すればいいはずだが、
 			// ATIではなぜかダメなようなので MIN/MAG 両方を設定している。
-			gl.glTexParameteri(GL2.GL_TEXTURE_RECTANGLE, GL2.GL_TEXTURE_MIN_FILTER, GL2.GL_NEAREST);
-			gl.glTexParameteri(GL2.GL_TEXTURE_RECTANGLE, GL2.GL_TEXTURE_MAG_FILTER, GL2.GL_NEAREST);
+			gl.glTexParameteri(GL2.GL_TEXTURE_2D, GL2.GL_TEXTURE_MIN_FILTER, GL2.GL_NEAREST);
+			gl.glTexParameteri(GL2.GL_TEXTURE_2D, GL2.GL_TEXTURE_MAG_FILTER, GL2.GL_NEAREST);
 
 		} else {
-			gl.glTexParameteri(GL2.GL_TEXTURE_RECTANGLE, GL2.GL_TEXTURE_MIN_FILTER, GL2.GL_LINEAR);
-			gl.glTexParameteri(GL2.GL_TEXTURE_RECTANGLE, GL2.GL_TEXTURE_MAG_FILTER, GL2.GL_LINEAR);
-			gl.glTexParameteri(GL2.GL_TEXTURE_RECTANGLE, GL2.GL_TEXTURE_WRAP_S, GL2.GL_CLAMP_TO_EDGE);
-			gl.glTexParameteri(GL2.GL_TEXTURE_RECTANGLE, GL2.GL_TEXTURE_WRAP_T, GL2.GL_CLAMP_TO_EDGE);
+			gl.glTexParameteri(GL2.GL_TEXTURE_2D, GL2.GL_TEXTURE_MIN_FILTER, GL2.GL_LINEAR);
+			gl.glTexParameteri(GL2.GL_TEXTURE_2D, GL2.GL_TEXTURE_MAG_FILTER, GL2.GL_LINEAR);
+			gl.glTexParameteri(GL2.GL_TEXTURE_2D, GL2.GL_TEXTURE_WRAP_S, GL2.GL_CLAMP_TO_EDGE);
+			gl.glTexParameteri(GL2.GL_TEXTURE_2D, GL2.GL_TEXTURE_WRAP_T, GL2.GL_CLAMP_TO_EDGE);
 		}
 
-		gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, 0);
+		gl.glBindTexture(GL2.GL_TEXTURE_2D, 0);
 	}
 
 	private Resolution autoResolution(Resolution prevResolution, double avgThreshold) {
