@@ -180,6 +180,28 @@ public abstract class LayerSwitchOperation extends ProjectOperation {
 		}
 	}
 
+	public static class Quality extends LayerSwitchOperation {
+
+		private final ch.kuramo.javie.core.Quality _newValue;
+		private final ch.kuramo.javie.core.Quality _oldValue;
+
+		public Quality(ProjectManager projectManager, Layer layer, ch.kuramo.javie.core.Quality newValue) {
+			super(projectManager, layer, "画質スイッチの変更");
+			_newValue = newValue;
+			_oldValue = LayerNature.getQuality(layer);
+			_noEffect = (_newValue == _oldValue);
+		}
+
+		@Override
+		protected void setSwitchValue(boolean undo, Layer layer, ProjectManager pm) {
+			LayerNature.setQuality(layer, undo ? _oldValue : _newValue);
+
+			if (pm != null) {
+				pm.fireLayerPropertyChange(layer, "quality");
+			}
+		}
+	}
+
 	public static class FrameBlend extends LayerSwitchOperation {
 		
 		private final ch.kuramo.javie.core.FrameBlend _newValue;
@@ -204,19 +226,22 @@ public abstract class LayerSwitchOperation extends ProjectOperation {
 
 	public static class MotionBlur extends LayerSwitchOperation {
 
-		private final boolean _oldValue;
+		private final ch.kuramo.javie.core.MotionBlur _newValue;
+		private final ch.kuramo.javie.core.MotionBlur _oldValue;
 
-		public MotionBlur(ProjectManager projectManager, Layer layer) {
+		public MotionBlur(ProjectManager projectManager, Layer layer, ch.kuramo.javie.core.MotionBlur newValue) {
 			super(projectManager, layer, "モーションブラースイッチの変更");
-			_oldValue = LayerNature.isMotionBlurEnabled(layer);
+			_newValue = newValue;
+			_oldValue = LayerNature.getMotionBlur(layer);
+			_noEffect = (_newValue == _oldValue);
 		}
 
 		@Override
 		protected void setSwitchValue(boolean undo, Layer layer, ProjectManager pm) {
-			LayerNature.setMotionBlurEnabled(layer, undo ? _oldValue : !_oldValue);
+			LayerNature.setMotionBlur(layer, undo ? _oldValue : _newValue);
 
 			if (pm != null) {
-				pm.fireLayerPropertyChange(layer, "motionBlurEnabled");
+				pm.fireLayerPropertyChange(layer, "motionBlur");
 			}
 		}
 	}
