@@ -138,7 +138,7 @@ import ch.kuramo.javie.app.actions.QTMovieOutputAction;
 import ch.kuramo.javie.app.actions.RemoveKeyframesAction;
 import ch.kuramo.javie.app.actions.RenameLayerOrEffectAction;
 import ch.kuramo.javie.app.actions.ReplaceLayerItemAction;
-import ch.kuramo.javie.app.actions.ResetAnimatableValuesAction;
+import ch.kuramo.javie.app.actions.ResetPropertiesAction;
 import ch.kuramo.javie.app.actions.ReverseLayerTimeAction;
 import ch.kuramo.javie.app.actions.SequenceOutputAction;
 import ch.kuramo.javie.app.actions.TimeRemapAction;
@@ -151,6 +151,7 @@ import ch.kuramo.javie.app.project.DuplicateLayersOperation;
 import ch.kuramo.javie.app.project.MoveEffectsOperation;
 import ch.kuramo.javie.app.project.NewCameraLayerOperation;
 import ch.kuramo.javie.app.project.NewLayerFromItemOperation;
+import ch.kuramo.javie.app.project.NewLightLayerOperation;
 import ch.kuramo.javie.app.project.NewNullLayerOperation;
 import ch.kuramo.javie.app.project.NewTextLayerOperation;
 import ch.kuramo.javie.app.project.ProjectEvent;
@@ -172,7 +173,9 @@ import ch.kuramo.javie.app.views.layercomp.LayerCompFrameBlendAction;
 import ch.kuramo.javie.app.views.layercomp.LayerCompMotionBlurAction;
 import ch.kuramo.javie.app.views.layercomp.LayerCompSettingsAction;
 import ch.kuramo.javie.app.views.layercomp.LayerCompShyAction;
+import ch.kuramo.javie.app.views.layercomp.LayerCompSuperSamplingAction;
 import ch.kuramo.javie.app.views.layercomp.LayerElement;
+import ch.kuramo.javie.app.views.layercomp.LayerPropertyElement;
 import ch.kuramo.javie.app.views.layercomp.TimelineManager;
 import ch.kuramo.javie.app.widgets.FontUtil;
 import ch.kuramo.javie.core.AnimatableLayerReference;
@@ -189,7 +192,9 @@ import ch.kuramo.javie.core.JavieRuntimeException;
 import ch.kuramo.javie.core.Keyframe;
 import ch.kuramo.javie.core.Layer;
 import ch.kuramo.javie.core.LayerComposition;
+import ch.kuramo.javie.core.LightLayer;
 import ch.kuramo.javie.core.MediaItem;
+import ch.kuramo.javie.core.MediaLayer;
 import ch.kuramo.javie.core.TimeCode;
 import ch.kuramo.javie.core.TransformableLayer;
 import ch.kuramo.javie.core.Util;
@@ -1008,6 +1013,12 @@ public class LayerCompositionView extends ViewPart
 			}
 		};
 
+		Action newLightLayerAction = new Action("ライト") {
+			public void run() {
+				handleNewLightLayerAction();
+			}
+		};
+
 		Action newCameraLayerAction = new Action("カメラ") {
 			public void run() {
 				handleNewCameraLayerAction();
@@ -1051,6 +1062,7 @@ public class LayerCompositionView extends ViewPart
 		actionBars.setGlobalActionHandler(CommandIds.DUPLICATE, duplicateAction);
 		actionBars.setGlobalActionHandler(CommandIds.SPLIT_LAYERS, _splitLayersAction);
 
+		actionBars.setGlobalActionHandler(CommandIds.NEW_LIGHT_LAYER, newLightLayerAction);
 		actionBars.setGlobalActionHandler(CommandIds.NEW_CAMERA_LAYER, newCameraLayerAction);
 		actionBars.setGlobalActionHandler(CommandIds.NEW_NULL_LAYER, newNullLayerAction);
 		actionBars.setGlobalActionHandler(CommandIds.NEW_TEXT_LAYER, newTextLayerAction);
@@ -1091,9 +1103,10 @@ public class LayerCompositionView extends ViewPart
 		menuMgr.add(_splitLayersAction);
 		menuMgr.add(new ReplaceLayerItemAction(this, _treeViewer));
 		menuMgr.add(new PrecomposeAction(this, _treeViewer));
-		menuMgr.add(new ResetAnimatableValuesAction(window, _treeViewer));
+		menuMgr.add(new ResetPropertiesAction(window, _treeViewer));
 		menuMgr.add(new GroupMarker(IWorkbenchActionConstants.MB_ADDITIONS));
 
+		newMenu.add(newLightLayerAction);
 		newMenu.add(newCameraLayerAction);
 		newMenu.add(newNullLayerAction);
 		newMenu.add(newTextLayerAction);
@@ -1630,8 +1643,10 @@ public class LayerCompositionView extends ViewPart
 		IToolBarManager tbm = actionBars.getToolBarManager();
 
 		tbm.add(new LayerCompShyAction(this));
+		tbm.add(new Separator());
 		tbm.add(new LayerCompFrameBlendAction(this));
 		tbm.add(new LayerCompMotionBlurAction(this));
+		tbm.add(new LayerCompSuperSamplingAction(this));
 		tbm.add(new Separator());
 		tbm.add(new LayerCompSettingsAction(this));
 
@@ -2053,6 +2068,39 @@ public class LayerCompositionView extends ViewPart
 		}
 	}
 
+	private TreeItem findLayerPropertyItem(TreeItem layerItem, final String property) {
+		return new Object() {
+			TreeItem find(TreeItem treeItem) {
+				Object element = treeItem.getData();
+				if (element instanceof LayerPropertyElement<?>
+						&& ((LayerPropertyElement<?>) element).getProperty().equals(property)) {
+					return treeItem;
+
+				} else if (treeItem.getItemCount() > 0) {
+					boolean expanded = _treeViewer.getExpandedState(element);
+					_treeViewer.getTree().setRedraw(false);
+					try {
+						_treeViewer.setExpandedState(element, true);
+
+						for (TreeItem ti : treeItem.getItems()) {
+							ti = find(ti);
+							if (ti != null) {
+								return ti;
+							}
+						}
+						return null;
+
+					} finally {
+						_treeViewer.setExpandedState(element, expanded);
+						_treeViewer.getTree().setRedraw(true);
+					}
+				} else {
+					return null;
+				}
+			}
+		}.find(layerItem);
+	}
+
 	private TreeItem findLayerAnimatableValueItem(TreeItem layerItem, final String property) {
 		return new Object() {
 			TreeItem find(TreeItem treeItem) {
@@ -2249,7 +2297,21 @@ public class LayerCompositionView extends ViewPart
 					treeItem = findLayerAnimatableValueItem(treeItem, event.property);
 
 				} else {
-					if (layerElement.layer instanceof TransformableLayer && event.property.equals("threeD")) {
+					if (layerElement.layer instanceof LightLayer && event.property.equals("lightType")) {
+						_treeViewer.refresh(layerElement, true);
+						treeItem = findLayerPropertyItem(treeItem, "lightType");
+
+					} else if (layerElement.layer instanceof LightLayer && event.property.equals("castsShadows")) {
+						treeItem = findLayerPropertyItem(treeItem, "castsShadows");
+
+					} else if (layerElement.layer instanceof MediaLayer
+							&& (event.property.equals("castsShadows")
+									|| event.property.equals("acceptsShadows")
+									|| event.property.equals("acceptsLights"))) {
+
+						treeItem = findLayerPropertyItem(treeItem, event.property);
+
+					} else if (layerElement.layer instanceof TransformableLayer && event.property.equals("threeD")) {
 						_treeViewer.refresh(layerElement, true);
 					} else {
 						_treeViewer.update(layerElement, null);
@@ -2609,18 +2671,45 @@ public class LayerCompositionView extends ViewPart
 			AnimatableValue<?> avalue;
 
 			if (effectIndex == -1) {
-				treeItem = findLayerAnimatableValueItem(layerItem, property);
-				avalue = PropertyUtil.getProperty(layer, property);
+				Object obj = PropertyUtil.getProperty(layer, property);
 
-				if (property.equals("timeRemap")) {
-					if (treeItem == null && avalue.hasKeyframe()) {
-						_treeViewer.refresh(layerItem.getData(), false);
-						treeItem = findLayerAnimatableValueItem(layerItem, property);
-					} else if (treeItem != null && !avalue.hasKeyframe()) {
-						_treeViewer.refresh(layerItem.getData(), false);
-						treeItem = null;
-						treeItems.add(layerItem);
+				if (obj instanceof AnimatableValue<?>) {
+					avalue = (AnimatableValue<?>) obj;
+					treeItem = findLayerAnimatableValueItem(layerItem, property);
+
+					if (property.equals("timeRemap")) {
+						if (treeItem == null && avalue.hasKeyframe()) {
+							_treeViewer.refresh(layerItem.getData(), false);
+							treeItem = findLayerAnimatableValueItem(layerItem, property);
+						} else if (treeItem != null && !avalue.hasKeyframe()) {
+							_treeViewer.refresh(layerItem.getData(), false);
+							treeItem = null;
+							treeItems.add(layerItem);
+						}
 					}
+				} else {
+					if (layer instanceof LightLayer && property.equals("lightType")) {
+						_treeViewer.refresh(layerItem.getData(), true);
+						treeItem = findLayerPropertyItem(layerItem, "lightType");
+
+					} else if (layer instanceof LightLayer && property.equals("castsShadows")) {
+						treeItem = findLayerPropertyItem(layerItem, "castsShadows");
+
+					} else if (layer instanceof MediaLayer
+							&& (property.equals("castsShadows")
+									|| property.equals("acceptsShadows")
+									|| property.equals("acceptsLights"))) {
+
+						treeItem = findLayerPropertyItem(layerItem, property);
+
+					} else {
+						treeItem = null;
+					}
+
+					if (treeItem != null) {
+						treeItems.add(treeItem);
+					}
+					continue;
 				}
 
 			} else {
@@ -2720,6 +2809,13 @@ public class LayerCompositionView extends ViewPart
 		collectAnimatableValues();
 	}
 
+	private void handleNewLightLayerAction() {
+		if (_projectManager != null && _composition != null) {
+			// TODO ライトの設定Wizardを作る
+			_projectManager.postOperation(new NewLightLayerOperation(_projectManager, _composition));
+		}
+	}
+
 	private void handleNewCameraLayerAction() {
 		if (_projectManager != null && _composition != null) {
 			// TODO カメラオプションの設定Wizardを作る
