@@ -119,8 +119,7 @@ public class AnimatableColorElementDelegate extends AnimatableValueElementDelega
 	}
 
 	private RGB getRGB() {
-		Color color = value.clamp();
-		return new RGB((int)Math.round(color.r*255), (int)Math.round(color.g*255), (int)Math.round(color.b*255));
+		return new RGB((int)Math.round(value.r*255), (int)Math.round(value.g*255), (int)Math.round(value.b*255));
 	}
 
 }
