@@ -62,6 +62,8 @@ import ch.kuramo.javie.core.JavieRuntimeException;
 import ch.kuramo.javie.core.Layer;
 import ch.kuramo.javie.core.LayerComposition;
 import ch.kuramo.javie.core.LayerNature;
+import ch.kuramo.javie.core.LightLayer;
+import ch.kuramo.javie.core.LightType;
 import ch.kuramo.javie.core.MediaLayer;
 import ch.kuramo.javie.core.NullLayer;
 import ch.kuramo.javie.core.TextLayer;
@@ -141,6 +143,12 @@ public class LayerElement extends Element {
 			switchesColumnSwitches.addPlaceholder();
 		}
 
+		if (LayerNature.isQualityNature(layer)) {
+			switchesColumnSwitches.add(new QualitySwitch(pm, layer));
+		} else {
+			switchesColumnSwitches.addPlaceholder();
+		}
+
 		if (layer instanceof EffectableLayer) {
 			switchesColumnSwitches.add(new EffectsSwitch(pm, (EffectableLayer) layer));
 		} else {
@@ -172,6 +180,9 @@ public class LayerElement extends Element {
 				if (layer instanceof ItemLayer<?>) {
 					return ImageUtil.getItemIcon(((ItemLayer<?>) layer).getItem());
 				}
+				if (layer instanceof LightLayer) {
+					return ImageUtil.getLightIcon();
+				}
 				if (layer instanceof CameraLayer) {
 					return ImageUtil.getCameraIcon();
 				}
@@ -290,11 +301,21 @@ public class LayerElement extends Element {
 		if (layer instanceof TransformableLayer && LayerNature.isVideoNature(layer)) {
 			children.add(getChildElement(TransformElement.class));
 
+		} else if (layer instanceof LightLayer) {
+			if (((LightLayer) layer).getLightType() != LightType.AMBIENT) {
+				children.add(getChildElement(LightTransformElement.class));
+			}
+			children.add(getChildElement(LightOptionsElement.class));
+
 		} else if (layer instanceof CameraLayer) {
 			children.add(getChildElement(CameraTransformElement.class));
 			children.add(getChildElement(CameraOptionsElement.class));
 		}
 
+		if (layer instanceof MediaLayer && LayerNature.isThreeD(layer)) {
+			children.add(getChildElement(MaterialOptionsElement.class));
+		}
+
 		if (layer instanceof MediaLayer && LayerNature.isAudioNature(layer)) {
 			children.add(getChildElement(AudioElement.class));
 		}
