@@ -40,6 +40,9 @@ import ch.kuramo.javie.core.EffectableLayer;
 import ch.kuramo.javie.core.FrameBlend;
 import ch.kuramo.javie.core.Layer;
 import ch.kuramo.javie.core.LayerNature;
+import ch.kuramo.javie.core.MediaLayer;
+import ch.kuramo.javie.core.MotionBlur;
+import ch.kuramo.javie.core.Quality;
 import ch.kuramo.javie.core.TransformableLayer;
 
 abstract class LayerSwitch implements Switch {
@@ -175,6 +178,32 @@ class CTCRSwitch extends LayerSwitch {
 
 }
 
+class QualitySwitch extends LayerSwitch {
+
+	public QualitySwitch(ProjectManager projectManager, Layer layer) {
+		super(projectManager, layer);
+	}
+
+	public Image getImage() {
+		switch (LayerNature.getQuality(layer)) {
+			case DRAFT:  return getImage(Activator.IMG_SWITCH_QUALITY_DRAFT);
+			case NORMAL: return getImage(Activator.IMG_SWITCH_QUALITY_NORMAL);
+			case BEST:   return getImage(Activator.IMG_SWITCH_QUALITY_BEST);
+			default:     return null;
+		}
+	}
+
+	public void mouseDown(MouseEvent event) {
+		Quality[] values = Quality.values();
+		Quality oldValue = LayerNature.getQuality(layer);
+		Quality newValue = values[(oldValue.ordinal() + 1) % values.length];
+
+		projectManager.postOperation(
+				new LayerSwitchOperation.Quality(projectManager, layer, newValue));
+	}
+
+}
+
 class FrameBlendSwitch extends LayerSwitch {
 
 	public FrameBlendSwitch(ProjectManager projectManager, Layer layer) {
@@ -210,13 +239,34 @@ class MotionBlurSwitch extends LayerSwitch {
 	}
 
 	public Image getImage() {
-		return LayerNature.isMotionBlurEnabled(layer)
-				? getImage(Activator.IMG_SWITCH_MBLUR) : null;
+		MotionBlur mblur = LayerNature.getMotionBlur(layer);
+
+		if (LayerNature.isCTCR(layer) && ((MediaLayer)layer).isVectorLayer()
+				&& mblur == MotionBlur.TRANSFORM) {
+
+			mblur = MotionBlur.FULL;
+		}
+
+		switch (mblur) {
+			case TRANSFORM:	return getImage(Activator.IMG_SWITCH_MBLUR_TRANSFORM);
+			case FULL:		return getImage(Activator.IMG_SWITCH_MBLUR_FULL);
+			default:		return null;
+		}
 	}
 
 	public void mouseDown(MouseEvent event) {
+		MotionBlur oldValue = LayerNature.getMotionBlur(layer);
+		MotionBlur newValue;
+
+		if (LayerNature.isCTCR(layer) && ((MediaLayer)layer).isVectorLayer()) {
+			newValue = (oldValue != MotionBlur.NONE) ? MotionBlur.NONE : MotionBlur.FULL;
+		} else {
+			MotionBlur[] values = MotionBlur.values();
+			newValue = values[(oldValue.ordinal() + 1) % values.length];
+		}
+
 		projectManager.postOperation(
-				new LayerSwitchOperation.MotionBlur(projectManager, layer));
+				new LayerSwitchOperation.MotionBlur(projectManager, layer, newValue));
 	}
 
 }
