@@ -373,7 +373,7 @@ public class TimelineManager {
 
 		seeking = true;
 		setWrapMode(false);
-		updateView(e.x, (e.stateMask & SWT.SHIFT) != 0, snapTimes);
+		updateView(e.x, (e.stateMask & SWT.SHIFT) != 0, snapTimes, Boolean.TRUE);
 
 		final Control control = (Control) e.widget;
 		final Display display = e.display;
@@ -385,7 +385,7 @@ public class TimelineManager {
 
 			public void run() {
 				if (!end) {
-					updateView(x, snap, snapTimes);
+					updateView(x, snap, snapTimes, Boolean.TRUE);
 					display.timerExec(30, this);
 				}
 			}
@@ -400,13 +400,17 @@ public class TimelineManager {
 
 							x = control.toControl(display.getCursorLocation()).x;
 							snap = (e.stateMask & SWT.SHIFT) != 0;
-							updateView(x, snap, snapTimes);
+							updateView(x, snap, snapTimes, Boolean.TRUE);
 							break;
 						}
 						// fall through
 
 					case SWT.MouseUp:
 					case SWT.Deactivate:
+						//if (!control.isDisposed()) {							// TODO disposeされてるかどうかのチェックは必要？
+							updateView(x, snap, snapTimes, Boolean.FALSE);		//      必要だとしても、スクラブ終了のイベントが送出されなくなるのはまずい。
+						//}
+
 						end = true;
 						display.removeFilter(SWT.MouseMove, this);
 						display.removeFilter(SWT.MouseUp, this);
@@ -426,7 +430,7 @@ public class TimelineManager {
 		display.addFilter(SWT.Deactivate, tracker);
 	}
 
-	private void updateView(int x, boolean snap, SortedSet<Time> snapTimes) {
+	private void updateView(int x, boolean snap, SortedSet<Time> snapTimes, Boolean scrubbing) {
 		Time frameDuration = composition.getFrameDuration();
 		int scroll = scrollSlider.getSelection();
 
@@ -455,7 +459,7 @@ public class TimelineManager {
 			}
 		}
 
-		setTime(time);
+		setTime(time, scrubbing);
 	}
 
 	public void drawLayer(Event e, Layer layer) {
@@ -782,16 +786,23 @@ public class TimelineManager {
 	}
 
 	public void setTime(Time time) {
+		setTime(time, null);
+	}
+
+	private void setTime(Time time, Boolean scrubbing) {
 		Time frameDuration = composition.getFrameDuration();
 		newTime = Time.fromFrameNumber(time.toFrameNumber(frameDuration), frameDuration);
 
 		if (!newTime.equals(currentTime)) {
-			view.update(newTime);
+			view.update(newTime, scrubbing);
 
 			if (seeking) {
 				//redraw();
 				meter.redraw();
 			}
+
+		} else if (Boolean.FALSE.equals(scrubbing)) {
+			view.update(newTime, scrubbing);
 		}
 	}
 
