@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -83,8 +83,6 @@ public class TransformElement extends Element {
 			createChildElement("rotationZ", "Z 回転", "°");
 
 			if (layer instanceof MediaLayer) {
-				createChildElement("depthBase", "深度基準点");
-				createIntersectionGroupElement();
 				createChildElement("opacity", "不透明度", "%");
 			}
 		} else {
@@ -117,8 +115,4 @@ public class TransformElement extends Element {
 		children.add(new LayerScaleElement(this, getLayer()));
 	}
 
-	private void createIntersectionGroupElement() {
-		children.add(new IntersectionGroupElement(this, getLayer()));
-	}
-
 }
