@@ -145,8 +145,7 @@ public class SolidColorItemWizardPage extends WizardPage {
 	}
 
 	private RGB getRGB() {
-		Color color = _color.clamp();
-		return new RGB((int)(color.r*255), (int)(color.g*255), (int)(color.b*255));
+		return new RGB((int)(_color.r*255), (int)(_color.g*255), (int)(_color.b*255));
 	}
 
 	private void setRGB(RGB rgb) {
