@@ -25,7 +25,6 @@ package ch.kuramo.javie.core;
 
 import ch.kuramo.javie.api.ICamera;
 import ch.kuramo.javie.api.Size2i;
-import ch.kuramo.javie.api.Vec3d;
 
 public interface Camera extends ICamera {
 
@@ -39,6 +38,4 @@ public interface Camera extends ICamera {
 
 	double[] getProjection3D();
 
-	Vec3d getPosition();
-
 }
