@@ -23,6 +23,7 @@
 
 package ch.kuramo.javie.core.internal;
 
+import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
 
@@ -34,24 +35,22 @@ import ch.kuramo.javie.api.IAudioBuffer;
 import ch.kuramo.javie.api.IObjectArray;
 import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.Resolution;
-import ch.kuramo.javie.api.Size2i;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.Vec2d;
-import ch.kuramo.javie.api.Vec3d;
 import ch.kuramo.javie.api.VideoBounds;
+import ch.kuramo.javie.api.services.IAccumulationSupport;
 import ch.kuramo.javie.api.services.IArrayPools;
+import ch.kuramo.javie.api.services.IVideoRenderSupport;
+import ch.kuramo.javie.core.AbstractAnimatableEnum;
 import ch.kuramo.javie.core.AbstractTransformableLayer;
 import ch.kuramo.javie.core.AnimatableDouble;
-import ch.kuramo.javie.core.AnimatableString;
 import ch.kuramo.javie.core.AnimatableVec2d;
-import ch.kuramo.javie.core.Camera;
-import ch.kuramo.javie.core.CollapseTransformation;
-import ch.kuramo.javie.core.Composition;
+import ch.kuramo.javie.core.CastsShadows;
 import ch.kuramo.javie.core.CoreContext;
-import ch.kuramo.javie.core.DepthBuffer;
 import ch.kuramo.javie.core.Effect;
 import ch.kuramo.javie.core.ExpressionScope;
 import ch.kuramo.javie.core.FrameBlend;
+import ch.kuramo.javie.core.Keyframe;
 import ch.kuramo.javie.core.LayerComposition;
 import ch.kuramo.javie.core.LayerNature;
 import ch.kuramo.javie.core.MediaInput;
@@ -59,16 +58,18 @@ import ch.kuramo.javie.core.MediaLayer;
 import ch.kuramo.javie.core.MotionBlur;
 import ch.kuramo.javie.core.Project;
 import ch.kuramo.javie.core.ProjectDecodeException;
+import ch.kuramo.javie.core.Quality;
 import ch.kuramo.javie.core.TrackMatte;
 import ch.kuramo.javie.core.Util;
 import ch.kuramo.javie.core.VectorMediaInput;
-import ch.kuramo.javie.core.VideoLayerBuffer;
-import ch.kuramo.javie.core.VideoLayerComposer;
-import ch.kuramo.javie.core.VideoLayerRenderer;
 import ch.kuramo.javie.core.WrappedOperation;
+import ch.kuramo.javie.core.VideoLayerRenderer.AbstractCRLayerRenderer;
+import ch.kuramo.javie.core.VideoLayerRenderer.AbstractNormalLayerRenderer;
+import ch.kuramo.javie.core.VideoLayerRenderer.CRLayerRenderer;
+import ch.kuramo.javie.core.VideoLayerRenderer.GeneralLayerRenderer;
+import ch.kuramo.javie.core.VideoLayerRenderer.NormalLayerRenderer;
 import ch.kuramo.javie.core.services.AudioEffectPipeline;
 import ch.kuramo.javie.core.services.AudioRenderSupport;
-import ch.kuramo.javie.core.services.GLGlobal;
 import ch.kuramo.javie.core.services.RenderContext;
 import ch.kuramo.javie.core.services.VideoEffectPipeline;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
@@ -81,14 +82,12 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 
 	private List<Effect> _effects = Util.newList();
 
-	private boolean _motionBlurEnabled = false;
+	private Quality _quality = Quality.NORMAL;
+
+	private MotionBlur _motionBlur = MotionBlur.NONE;
 
 	private TrackMatte _trackMatte = TrackMatte.NONE;
 
-	private AnimatableVec2d _depthBase = new AnimatableVec2d(new Vec2d(0, 0));
-
-	private AnimatableString _intersectionGroup = new AnimatableString("");
-
 	private AnimatableDouble _opacity = new AnimatableDouble(100d, 0d, 100d);
 
 	private BlendMode _blendMode = BlendMode.NORMAL;
@@ -97,17 +96,38 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 
 	private AnimatableDouble _timeRemap = new AnimatableDouble(0.0);
 
+	private CastsShadows _castsShadows = CastsShadows.OFF;
+
+	private AnimatableDouble _lightTransmission = new AnimatableDouble(0d, 0d, 100d);
+
+	private boolean _acceptsShadows = true;
+
+	private boolean _acceptsLights = true;
+
+	private AnimatableDouble _ambient = new AnimatableDouble(100d, 0d, 100d);
+
+	private AnimatableDouble _diffuse = new AnimatableDouble(50d, 0d, 100d);
+
+	private AnimatableDouble _specular = new AnimatableDouble(50d, 0d, 100d);
+
+	private AnimatableDouble _shininess = new AnimatableDouble(5d, 0d, 100d);
+
+	private AnimatableDouble _metal = new AnimatableDouble(100d, 0d, 100d);
+
 	@Inject
 	private RenderContext _context;
 
 	@Inject
-	private VideoRenderSupport _vrSupport;
+	private IVideoRenderSupport _support;
+
+	@Inject
+	private VideoRenderSupport _oldSupport;
 
 	@Inject
 	private VideoEffectPipeline _vePipeline;
 
 	@Inject
-	private GLGlobal _glGlobal;
+	private IAccumulationSupport _accumSuport;
 
 	@Inject
 	private AudioRenderSupport _arSupport;
@@ -145,12 +165,20 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		_effects = effects;
 	}
 
-	public boolean isMotionBlurEnabled() {
-		return _motionBlurEnabled;
+	public Quality getQuality() {
+		return _quality;
 	}
 
-	public void setMotionBlurEnabled(boolean motionBlurEnabled) {
-		_motionBlurEnabled = motionBlurEnabled;
+	public void setQuality(Quality quality) {
+		_quality = quality;
+	}
+
+	public MotionBlur getMotionBlur() {
+		return _motionBlur;
+	}
+
+	public void setMotionBlur(MotionBlur motionBlur) {
+		_motionBlur = motionBlur;
 	}
 
 	public TrackMatte getTrackMatte() {
@@ -161,24 +189,6 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		_trackMatte = trackMatte;
 	}
 
-	public AnimatableVec2d getDepthBase() {
-		return _depthBase;
-	}
-
-	public void setDepthBase(AnimatableVec2d depthBase) {
-		depthBase.copyConfigurationFrom(_depthBase);
-		_depthBase = depthBase;
-	}
-
-	public AnimatableString getIntersectionGroup() {
-		return _intersectionGroup;
-	}
-
-	public void setIntersectionGroup(AnimatableString intersectionGroup) {
-		intersectionGroup.copyConfigurationFrom(_intersectionGroup);
-		_intersectionGroup = intersectionGroup;
-	}
-
 	public AnimatableDouble getOpacity() {
 		return _opacity;
 	}
@@ -214,6 +224,84 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		_timeRemap = timeRemap;
 	}
 
+	public CastsShadows getCastsShadows() {
+		return _castsShadows;
+	}
+
+	public void setCastsShadows(CastsShadows castsShadows) {
+		_castsShadows = castsShadows;
+	}
+
+	public AnimatableDouble getLightTransmission() {
+		return _lightTransmission;
+	}
+
+	public void setLightTransmission(AnimatableDouble lightTransmission) {
+		lightTransmission.copyConfigurationFrom(_lightTransmission);
+		_lightTransmission = lightTransmission;
+	}
+
+	public boolean isAcceptsShadows() {
+		return _acceptsShadows;
+	}
+
+	public void setAcceptsShadows(boolean acceptsShadows) {
+		_acceptsShadows = acceptsShadows;
+	}
+
+	public boolean isAcceptsLights() {
+		return _acceptsLights;
+	}
+
+	public void setAcceptsLights(boolean acceptsLights) {
+		_acceptsLights = acceptsLights;
+	}
+
+	public AnimatableDouble getAmbient() {
+		return _ambient;
+	}
+
+	public void setAmbient(AnimatableDouble ambient) {
+		ambient.copyConfigurationFrom(_ambient);
+		_ambient = ambient;
+	}
+
+	public AnimatableDouble getDiffuse() {
+		return _diffuse;
+	}
+
+	public void setDiffuse(AnimatableDouble diffuse) {
+		diffuse.copyConfigurationFrom(_diffuse);
+		_diffuse = diffuse;
+	}
+
+	public AnimatableDouble getSpecular() {
+		return _specular;
+	}
+
+	public void setSpecular(AnimatableDouble specular) {
+		specular.copyConfigurationFrom(_specular);
+		_specular = specular;
+	}
+
+	public AnimatableDouble getShininess() {
+		return _shininess;
+	}
+
+	public void setShininess(AnimatableDouble shininess) {
+		shininess.copyConfigurationFrom(_shininess);
+		_shininess = shininess;
+	}
+
+	public AnimatableDouble getMetal() {
+		return _metal;
+	}
+
+	public void setMetal(AnimatableDouble metal) {
+		metal.copyConfigurationFrom(_metal);
+		_metal = metal;
+	}
+
 	public boolean isVectorLayer() {
 		return (getMediaInput() instanceof VectorMediaInput);
 	}
@@ -222,39 +310,167 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 	public void prepareExpression(ExpressionScope scope) {
 		super.prepareExpression(scope);
 
-		scope.assignTo(_depthBase);
-		scope.assignTo(_intersectionGroup);
 		scope.assignTo(_opacity);
 		scope.assignTo(_audioLevels);
 		scope.assignTo(_timeRemap);
 
+		scope.assignTo(_lightTransmission);
+		scope.assignTo(_ambient);
+		scope.assignTo(_diffuse);
+		scope.assignTo(_specular);
+		scope.assignTo(_shininess);
+		scope.assignTo(_metal);
+
 		for (Effect effect : _effects) {
 			effect.prepareExpression(scope.clone());
 		}
 	}
 
-	public void setupVideoRenderer(
-			VideoLayerComposer composer, CollapseTransformation ct,
-			MotionBlur motinBlur, boolean frameBlendEnabled,
-			boolean withEffects, boolean withTransformation) {
-
-		// トラックマット適用時やエフェクトからの参照時にこのチェックがあるとまずいので。同じチェックはコンポ側でもしている。
+	public GeneralLayerRenderer createVideoRenderer() {
+		// エフェクトからの参照時にこのチェックがあるとまずいので。同じチェックはコンポ側でもしている。
 		//if (!LayerNature.isVideoEnabled(this)) {
 		//	return;
 		//}
 
 		MediaInput input = getMediaInput();
 		if (input == null || !input.isVideoAvailable()) {
-			return;
+			return null;
 		}
 
 		if (isVectorLayer() && LayerNature.isCTCR(this)) {
-			setupVideoRendererCR(composer, ct, motinBlur, withEffects);
+			return createCRLayerRenderer();
 		} else {
-			setupVideoRendererNormal(composer, ct, motinBlur, frameBlendEnabled, withEffects, withTransformation);
+			return createNormalLayerRenderer();
 		}
 	}
 
+	private NormalLayerRenderer createNormalLayerRenderer() {
+		return new AbstractNormalLayerRenderer() {
+
+			public MediaLayer getLayer() {
+				return AbstractMediaLayer.this;
+			}
+
+			public double getOpacity() {
+				return _opacity.value(_context) / 100;
+			}
+
+			public void multModelViewMatrix(double[] mvMatrix) {
+				_oldSupport.setMatrix(mvMatrix, null);
+				LayerMatrixUtil.multModelViewMatrix(AbstractMediaLayer.this, _context, _oldSupport);
+				_oldSupport.getMatrix(mvMatrix, null);
+			}
+
+			public VideoBounds calcBounds(boolean withEffects) {
+				return _vePipeline.getVideoBounds(getEffects(withEffects), inputBoundsOperation);
+			}
+
+			public IVideoBuffer render(boolean withEffects, boolean frameBlendEnabled) {
+				return _vePipeline.doVideoEffects(getEffects(withEffects), inputBoundsOperation,
+													createInputBufferOperation(frameBlendEnabled));
+			}
+
+			private List<Effect> getEffects(boolean withEffects) {
+				return (withEffects && _effectsEnabled) ? _effects : Collections.<Effect>emptyList();
+			}
+
+			private final WrappedOperation<VideoBounds> inputBoundsOperation = new WrappedOperation<VideoBounds>() {
+				public VideoBounds execute() {
+					return _context.getVideoResolution().scale(getMediaInput().getVideoFrameBounds());
+				}
+			};
+
+			private WrappedOperation<IVideoBuffer> createInputBufferOperation(final boolean frameBlendEnabled) {
+				return new WrappedOperation<IVideoBuffer>() {
+					public IVideoBuffer execute() {
+						if (frameBlendEnabled) {
+							FrameBlend frameBlend = LayerNature.getFrameBlend(AbstractMediaLayer.this);
+							if (frameBlend != FrameBlend.NONE) {
+								return blendFrames(frameBlend);
+							}
+						}
+						MediaInput input = getMediaInput();
+						return input.getVideoFrame(calcVideoMediaTime(input));
+					}
+				};
+			}
+		};
+	}
+
+	private CRLayerRenderer createCRLayerRenderer() {
+		return new AbstractCRLayerRenderer() {
+
+			public MediaLayer getLayer() {
+				return AbstractMediaLayer.this;
+			}
+
+			public double getOpacity() {
+				return _opacity.value(_context) / 100;
+			}
+
+			public void multModelViewMatrix(double[] mvMatrix) {
+				_oldSupport.setMatrix(mvMatrix, null);
+				LayerMatrixUtil.multModelViewMatrix(AbstractMediaLayer.this, _context, _oldSupport);
+				_oldSupport.getMatrix(mvMatrix, null);
+			}
+
+			public VideoBounds calcBounds(boolean withEffects, VideoBounds viewport) {
+				return _vePipeline.getVideoBounds(getEffects(withEffects), createInputBoundsOperation(viewport));
+			}
+
+			public IVideoBuffer render(boolean withEffects, VideoBounds viewport, double[] mvMatrix, double[] prjMatrix) {
+				return _vePipeline.doVideoEffects(getEffects(withEffects),
+						createInputBoundsOperation(viewport),
+						createInputBufferOperation(viewport, mvMatrix, prjMatrix));
+			}
+
+			public IVideoBuffer render() {
+				return _context.saveAndExecute(new WrappedOperation<IVideoBuffer>() {
+					public IVideoBuffer execute() {
+						MediaInput input = getMediaInput();
+						return input.getVideoFrame(calcVideoMediaTime(input));
+					}
+				});
+			}
+
+			private List<Effect> getEffects(boolean withEffects) {
+				return (withEffects && _effectsEnabled) ? _effects : Collections.<Effect>emptyList();
+			}
+
+			private WrappedOperation<VideoBounds> createInputBoundsOperation(final VideoBounds viewport) {
+				return new WrappedOperation<VideoBounds>() {
+					public VideoBounds execute() {
+						return viewport;
+					}
+				};
+			}
+
+			private WrappedOperation<IVideoBuffer> createInputBufferOperation(
+					final VideoBounds bounds, final double[] mvMatrix, final double[] prjMatrix) {
+
+				return new WrappedOperation<IVideoBuffer>() {
+					public IVideoBuffer execute() {
+						IVideoBuffer rasterizedBuffer = null;
+						try {
+							rasterizedBuffer = _support.createVideoBuffer(bounds, _context.getColorMode());
+							rasterizedBuffer.clear();
+
+							VectorMediaInput input = (VectorMediaInput) getMediaInput();
+							input.rasterize(rasterizedBuffer, mvMatrix, prjMatrix, calcVideoMediaTime(input));
+
+							IVideoBuffer result = rasterizedBuffer;
+							rasterizedBuffer = null;
+							return result;
+
+						} finally {
+							if (rasterizedBuffer != null) rasterizedBuffer.dispose();
+						}
+					}
+				};
+			}
+		};
+	}
+
 	protected Time calcVideoMediaTime(MediaInput input) {
 		Time time;
 
@@ -306,292 +522,6 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		return time;
 	}
 
-	private void setupVideoRendererNormal(
-			VideoLayerComposer composer, final CollapseTransformation ct,
-			final MotionBlur motionBlur, final boolean frameBlendEnabled,
-			final boolean withEffects, final boolean withTransformation) {
-
-		final MediaInput input = getMediaInput();
-		final Resolution resolution = _context.getVideoResolution();
-
-		final WrappedOperation<VideoBounds> inputBoundsOperation = new WrappedOperation<VideoBounds>() {
-			public VideoBounds execute() {
-				return resolution.scale(input.getVideoFrameBounds());
-			}
-		};
-
-		final List<Effect> effects = (withEffects && _effectsEnabled) ? _effects : Collections.<Effect>emptyList();
-
-		VideoBounds bounds = _vePipeline.getVideoBounds(effects, inputBoundsOperation);
-		final Vec2d offset = new Vec2d(-bounds.x/resolution.scale, -bounds.y/resolution.scale);
-
-		final double[] mvMatrix;
-		final double[] prjMatrix;
-		if (withTransformation) {
-			mvMatrix = new double[16];
-			prjMatrix = new double[16];
-			createMatrix(ct, offset, mvMatrix, prjMatrix);
-		} else {
-			mvMatrix = null;
-			prjMatrix = null;
-		}
-
-
-		final Time time = _context.getTime();
-		final Composition comp = _context.getComposition();
-		final Camera camera = _context.getCamera();
-
-		VideoLayerRenderer r = new VideoLayerRenderer() {
-			public VideoLayerBuffer render(boolean withDepthBuffer) {
-				// コラップスしているときはここで時刻とコンポ、カメラを再度設定する必要がある。
-				_context.setTime(time);
-				_context.setComposition(comp);
-				_context.setCamera(camera);
-
-				final double opacity;
-				if (ct == null) {
-					opacity = _opacity.value(_context) / 100d;
-				} else {
-					opacity = _opacity.value(_context) / 100d * ct.getOpacity();
-				}
-
-				IVideoBuffer effectedBuffer = null;
-				IVideoBuffer trnsfrmdBuffer = null;
-				DepthBuffer depthBuffer = null;
-				try {
-					WrappedOperation<IVideoBuffer> inputBufferOperation = new WrappedOperation<IVideoBuffer>() {
-						public IVideoBuffer execute() {
-							if (frameBlendEnabled) {
-								FrameBlend frameBlend = LayerNature.getFrameBlend(AbstractMediaLayer.this);
-								if (frameBlend != FrameBlend.NONE) {
-									return blendFrames(frameBlend);
-								}
-							}
-							return input.getVideoFrame(calcVideoMediaTime(input));
-						}
-					};
-
-					effectedBuffer = _vePipeline.doVideoEffects(effects, inputBoundsOperation, inputBufferOperation);
-
-					if (withTransformation) {
-						if (motionBlur != null && LayerNature.isMotionBlurEnabled(AbstractMediaLayer.this)) {
-							if (withDepthBuffer) {
-								depthBuffer = _vrSupport.createDepthBuffer(camera.getViewportSize());
-								_vrSupport.fillDepth(depthBuffer, mvMatrix, prjMatrix);
-							}
-
-							final IVideoBuffer mblurSrcBuf = effectedBuffer;
-							MotionBlurSampler sampler = new MotionBlurSampler() {
-								public void sample(double[] mvMatrix, double[] prjMatrix, IVideoBuffer buffer) {
-									_vrSupport.transform(mblurSrcBuf, buffer, null, mvMatrix, prjMatrix);
-								}
-							};
-							trnsfrmdBuffer = renderWithMotionBlur(ct, motionBlur, offset, time, sampler);
-
-						} else {
-							trnsfrmdBuffer = _vrSupport.createVideoBuffer(_context.getColorMode(), camera.getViewportSize());
-							trnsfrmdBuffer.clear();
-
-							if (withDepthBuffer) {
-								depthBuffer = _vrSupport.createDepthBuffer(camera.getViewportSize());
-								_vrSupport.transform(effectedBuffer, trnsfrmdBuffer, depthBuffer, mvMatrix, prjMatrix);
-							} else {
-								_vrSupport.transform(effectedBuffer, trnsfrmdBuffer, null, mvMatrix, prjMatrix);
-							}
-						}
-					} else {
-						if (withDepthBuffer) {
-							throw new IllegalArgumentException("can't create DepthBuffer when withTransformation is false");
-						}
-						trnsfrmdBuffer = effectedBuffer;
-						effectedBuffer = null;
-					}
-
-					VideoLayerBuffer vlb = new VideoLayerBufferImpl(trnsfrmdBuffer, depthBuffer,
-							_blendMode, opacity, getId().hashCode() + getName().hashCode());
-					trnsfrmdBuffer = null;
-					depthBuffer = null;
-					return vlb;
-
-				} finally {
-					if (depthBuffer != null) depthBuffer.dispose();
-					if (trnsfrmdBuffer != null) trnsfrmdBuffer.dispose();
-					if (effectedBuffer != null) effectedBuffer.dispose();
-				}
-			}
-		};
-
-		if (withTransformation && LayerNature.isThreeD(this)) {
-			Vec2d depthBase2d = _depthBase.value(_context);
-			Vec3d depthBase = new Vec3d(depthBase2d.x + offset.x, depthBase2d.y + offset.y);
-			depthBase = resolution.scale(depthBase);
-
-			Size2i vp = camera.getViewportSize();
-			Vec3d[] vertices = new Vec3d[] {
-				_vrSupport.project(depthBase, mvMatrix, prjMatrix, vp),
-				_vrSupport.project(new Vec3d(bounds.x               , bounds.y                ), mvMatrix, prjMatrix, vp),
-				_vrSupport.project(new Vec3d(bounds.x + bounds.width, bounds.y                ), mvMatrix, prjMatrix, vp),
-				_vrSupport.project(new Vec3d(bounds.x + bounds.width, bounds.y + bounds.height), mvMatrix, prjMatrix, vp),
-				_vrSupport.project(new Vec3d(bounds.x               , bounds.y + bounds.height), mvMatrix, prjMatrix, vp)
-			};
-			composer.add3D(r, vertices, _intersectionGroup.value(_context));
-
-		} else {
-			composer.add2D(r);
-		}
-	}
-
-	private void setupVideoRendererCR(
-			VideoLayerComposer composer, final CollapseTransformation ct,
-			final MotionBlur motionBlur, final boolean withEffects) {
-
-		final VectorMediaInput input = (VectorMediaInput) getMediaInput();
-		Resolution resolution = _context.getVideoResolution();
-
-		VideoBounds bounds = resolution.scale(input.getVideoFrameBounds());
-
-		final double[] mvMatrix = new double[16];
-		final double[] prjMatrix = new double[16];
-		createMatrix(ct, null, mvMatrix, prjMatrix);
-
-
-		final Time time = _context.getTime();
-		final Composition comp = _context.getComposition();
-		final Camera camera = _context.getCamera();
-
-		VideoLayerRenderer r = new VideoLayerRenderer() {
-			public VideoLayerBuffer render(boolean withDepthBuffer) {
-				// コラップスしているときはここで時刻とコンポ、カメラを再度設定する必要がある。
-				_context.setTime(time);
-				_context.setComposition(comp);
-				_context.setCamera(camera);
-
-				final double opacity;
-				if (ct == null) {
-					opacity = _opacity.value(_context) / 100d;
-				} else {
-					opacity = _opacity.value(_context) / 100d * ct.getOpacity();
-				}
-
-				IVideoBuffer effectedBuffer = null;
-				IVideoBuffer resultBuffer = null;
-				DepthBuffer depthBuffer = null;
-				try {
-					if (withDepthBuffer) {
-						depthBuffer = _vrSupport.createDepthBuffer(camera.getViewportSize());
-						_vrSupport.fillDepth(depthBuffer, mvMatrix, prjMatrix);
-					}
-
-					WrappedOperation<VideoBounds> inputBoundsOperation = new WrappedOperation<VideoBounds>() {
-						public VideoBounds execute() {
-							return new VideoBounds(camera.getViewportSize());
-						}
-					};
-
-					WrappedOperation<IVideoBuffer> inputBufferOperation = new WrappedOperation<IVideoBuffer>() {
-						public IVideoBuffer execute() {
-							IVideoBuffer rasterizedBuffer = null;
-							try {
-								if (motionBlur != null && LayerNature.isMotionBlurEnabled(AbstractMediaLayer.this)) {
-									MotionBlurSampler sampler = new MotionBlurSampler() {
-										public void sample(double[] mvMatrix, double[] prjMatrix, IVideoBuffer buffer) {
-											input.rasterize(buffer, mvMatrix, prjMatrix, calcVideoMediaTime(input));
-										}
-									};
-									rasterizedBuffer = renderWithMotionBlur(ct, motionBlur, null, _context.getTime(), sampler);
-
-								} else {
-									rasterizedBuffer = _vrSupport.createVideoBuffer(_context.getColorMode(), camera.getViewportSize());
-									rasterizedBuffer.clear();
-
-									input.rasterize(rasterizedBuffer, mvMatrix, prjMatrix, calcVideoMediaTime(input));
-								}
-
-								IVideoBuffer result = rasterizedBuffer;
-								rasterizedBuffer = null;
-								return result;
-
-							} finally {
-								if (rasterizedBuffer != null) rasterizedBuffer.dispose();
-							}
-						}
-					};
-
-					if (withEffects) {
-						effectedBuffer = _vePipeline.doVideoEffects(
-								_effectsEnabled ? _effects : Collections.<Effect>emptyList(),
-								inputBoundsOperation, inputBufferOperation);
-
-						VideoBounds resultBounds = new VideoBounds(camera.getViewportSize());
-						if (effectedBuffer.getBounds().equals(resultBounds)) {
-							resultBuffer = effectedBuffer;
-							effectedBuffer = null;
-						} else {
-							resultBuffer = _vrSupport.createVideoBuffer(_context.getColorMode(), resultBounds);
-							resultBuffer.clear();
-							_vrSupport.copy(effectedBuffer, resultBuffer);
-						}
-					} else {
-						resultBuffer = _context.saveAndExecute(inputBufferOperation);
-					}
-
-					VideoLayerBuffer vlb = new VideoLayerBufferImpl(resultBuffer, depthBuffer,
-							_blendMode, opacity, getId().hashCode() + getName().hashCode());
-					resultBuffer = null;
-					depthBuffer = null;
-					return vlb;
-
-				} finally {
-					if (depthBuffer != null) depthBuffer.dispose();
-					if (resultBuffer != null) resultBuffer.dispose();
-					if (effectedBuffer != null) effectedBuffer.dispose();
-				}
-			}
-		};
-
-		if (LayerNature.isThreeD(this)) {
-			Vec2d depthBase2d = _depthBase.value(_context);
-			Vec3d depthBase = new Vec3d(depthBase2d.x, depthBase2d.y);
-			depthBase = resolution.scale(depthBase);
-
-			Size2i vp = camera.getViewportSize();
-			Vec3d[] vertices = new Vec3d[] {
-				_vrSupport.project(depthBase, mvMatrix, prjMatrix, vp),
-				_vrSupport.project(new Vec3d(bounds.x               , bounds.y                ), mvMatrix, prjMatrix, vp),
-				_vrSupport.project(new Vec3d(bounds.x + bounds.width, bounds.y                ), mvMatrix, prjMatrix, vp),
-				_vrSupport.project(new Vec3d(bounds.x + bounds.width, bounds.y + bounds.height), mvMatrix, prjMatrix, vp),
-				_vrSupport.project(new Vec3d(bounds.x               , bounds.y + bounds.height), mvMatrix, prjMatrix, vp)
-			};
-			composer.add3D(r, vertices, _intersectionGroup.value(_context));
-
-		} else {
-			composer.add2D(r);
-		}
-	}
-
-	private void createMatrix(
-			final CollapseTransformation ct, final Vec2d offset,
-			final double[] mvMatrix, final double[] prjMatrix) {
-
-		WrappedOperation<Object> operation = new WrappedOperation<Object>() {
-			public Object execute() {
-				Camera camera = _context.getCamera();
-				if (LayerNature.isThreeD(AbstractMediaLayer.this)) {
-					_vrSupport.setMatrix(camera.getModelView3D(), camera.getProjection3D());
-				} else {
-					_vrSupport.setMatrix(camera.getModelView2D(), camera.getProjection2D());
-				}
-
-				LayerMatrixUtil.multModelViewMatrix(AbstractMediaLayer.this, offset, ct, _context, _vrSupport);
-
-				_vrSupport.getMatrix(mvMatrix, prjMatrix);
-				return null;
-			}
-		};
-
-		_vrSupport.pushMatrixAndExecute(operation);
-	}
-
 	private IVideoBuffer blendFrames(FrameBlend frameBlend) {
 		if (frameBlend == FrameBlend.NONE) throw new IllegalArgumentException();
 		if (frameBlend != FrameBlend.FRAME_MIX) throw new UnsupportedOperationException();
@@ -615,16 +545,20 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 
 
 		List<IVideoBuffer> buffers = Util.newList();
-		IVideoBuffer buf32f = null;
+		IVideoBuffer accumBuf = null;
 		try {
 			Resolution resolution = _context.getVideoResolution();
 			VideoBounds bounds = resolution.scale(input.getVideoFrameBounds());
+			ColorMode ctxColorMode = _context.getColorMode();
 
-			buf32f = _vrSupport.createVideoBuffer(ColorMode.RGBA32_FLOAT, bounds);
-			buf32f.clear();
+			// 不動小数テクスチャ使ってもほとんど差は出ないかも。
+			accumBuf = ctxColorMode.isFloat()
+					? _support.createVideoBuffer(bounds, ctxColorMode)
+					: _support.createVideoBuffer(bounds, ColorMode.RGBA16_FLOAT);
+			accumBuf.clear();
 
 			List<Double> weights = Util.newList();
-			int maxUnits = _glGlobal.getMaxTextureImageUnits();
+			int maxSources = _accumSuport.getMaxSourcesAtATime();
 
 			if (fpsRatio > 1) {
 				List<Integer> intWeights = Util.newList();
@@ -652,8 +586,8 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 					buffers.add(input.getVideoFrame(t));
 					weights.add(intWeights.get(Math.abs(i))/255.0);
 
-					if (buffers.size() >= maxUnits) {
-						_vrSupport.accumulate(buffers, weights, buf32f);
+					if (buffers.size() >= maxSources) {
+						_accumSuport.accumulate(buffers, weights, accumBuf);
 						for (IVideoBuffer vb : buffers) vb.dispose();
 						buffers.clear();
 						weights.clear();
@@ -675,9 +609,9 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 				buffers.add(input.getVideoFrame(t0));
 				weights.add((double)tv1/(tv0+tv1));
 
-				// maxUnitsが1の場合はあるのか？　無いのなら次のifブロックは不要。
-				if (maxUnits == 1) {
-					_vrSupport.accumulate(buffers, weights, buf32f);
+				// maxSourcesが1の場合はあるのか？　無いのなら次のifブロックは不要。
+				if (maxSources == 1) {
+					_accumSuport.accumulate(buffers, weights, accumBuf);
 					buffers.get(0).dispose();
 					buffers.clear();
 					weights.clear();
@@ -687,89 +621,28 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 				weights.add((double)tv0/(tv0+tv1));
 			}
 			if (!buffers.isEmpty()) {
-				_vrSupport.accumulate(buffers, weights, buf32f);
+				_accumSuport.accumulate(buffers, weights, accumBuf);
 			}
 
 			IVideoBuffer resultBuffer;
-			if (_context.getColorMode() == ColorMode.RGBA32_FLOAT) {
-				resultBuffer = buf32f;
-				buf32f = null;
+			if (accumBuf.getColorMode() == ctxColorMode) {
+				resultBuffer = accumBuf;
+				accumBuf = null;
 			} else {
-				resultBuffer = _vrSupport.createVideoBuffer(_context.getColorMode(), buf32f.getBounds());
-				_vrSupport.copy(buf32f, resultBuffer);
-			}
-			return resultBuffer;
-		} finally {
-			for (IVideoBuffer vb : buffers) vb.dispose();
-			if (buf32f != null) buf32f.dispose();
-		}
-	}
-
-	private interface MotionBlurSampler {
-		void sample(double[] mvMatrix, double[] prjMatrix, IVideoBuffer buffer);
-	}
-
-	private IVideoBuffer renderWithMotionBlur(
-			CollapseTransformation ct, MotionBlur motionBlur,
-			Vec2d offset, Time time, MotionBlurSampler sampler) {
-
-		List<IVideoBuffer> buffers = Util.newList();
-		IVideoBuffer buf = null;
-		IVideoBuffer buf32f = null;
-		try {
-			Size2i vpSize = _context.getCamera().getViewportSize();
-
-			buf32f = _vrSupport.createVideoBuffer(ColorMode.RGBA32_FLOAT, vpSize);
-			buf32f.clear();
-
-			double shutterAngle = motionBlur.getShutterAngle();
-			double shutterPhase = motionBlur.getShutterPhase();
-			int samples = motionBlur.getSamples();
-			Time frameDuration = _context.getVideoFrameDuration();
-			int maxUnits = _glGlobal.getMaxTextureImageUnits();
-
-			double[] mvMatrix = new double[16];
-			double[] prjMatrix = new double[16];
-
-			for (int i = 0; i < samples; ++i) {
-				double angle = shutterPhase + shutterAngle*i/samples;
-				Time t = time.add(new Time((long)(frameDuration.timeValue*angle/360), frameDuration.timeScale));
-				_context.setTime(t);
-
-				createMatrix(ct, offset, mvMatrix, prjMatrix);
-
-				buf = _vrSupport.createVideoBuffer(_context.getColorMode(), vpSize);
-				buf.clear();
-
-				sampler.sample(mvMatrix, prjMatrix, buf);
-
-				buffers.add(buf);
-				buf = null;
-
-				if (buffers.size() >= maxUnits) {
-					_vrSupport.accumulate(buffers, 1.0/samples, buf32f);
-					for (IVideoBuffer vb : buffers) vb.dispose();
-					buffers.clear();
+				IVideoBuffer copy = null;
+				try {
+					copy = _support.createVideoBuffer(bounds, ctxColorMode);
+					_support.copy(accumBuf, copy);
+					resultBuffer = copy;
+					copy = null;
+				} finally {
+					if (copy != null) copy.dispose();
 				}
 			}
-			if (!buffers.isEmpty()) {
-				_vrSupport.accumulate(buffers, 1.0/samples, buf32f);
-			}
-
-			IVideoBuffer resultBuffer;
-			if (_context.getColorMode() == ColorMode.RGBA32_FLOAT) {
-				resultBuffer = buf32f;
-				buf32f = null;
-			} else {
-				resultBuffer = _vrSupport.createVideoBuffer(_context.getColorMode(), buf32f.getBounds());
-				_vrSupport.copy(buf32f, resultBuffer);
-			}
 			return resultBuffer;
-
 		} finally {
 			for (IVideoBuffer vb : buffers) vb.dispose();
-			if (buf != null) buf.dispose();
-			if (buf32f != null) buf32f.dispose();
+			if (accumBuf != null) accumBuf.dispose();
 		}
 	}
 
@@ -940,7 +813,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		}
 	}
 
-	public IAudioBuffer renderAudioChunk(boolean withEffects, boolean withLevelsAndInOut) {
+	public IAudioBuffer renderAudioChunk(boolean rawSource) {
 		// エフェクトからの参照時にこのチェックがあるとまずいので。同じチェックはコンポ側でもしている。
 		//if (!LayerNature.isAudioEnabled(this)) {
 		//	return null;
@@ -969,9 +842,9 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		};
 
 		IAudioBuffer ab = _aePipeline.doAudioEffects(
-				(withEffects && _effectsEnabled) ? _effects : Collections.<Effect>emptyList(), inputOperation);
+				(!rawSource && _effectsEnabled) ? _effects : Collections.<Effect>emptyList(), inputOperation);
 
-		if (withLevelsAndInOut) {
+		if (!rawSource) {
 			if (_audioLevels.hasKeyframe() || _audioLevels.getExpression() != null
 					|| !_audioLevels.getStaticValue().equals(Vec2d.ZERO)) {
 
@@ -1022,12 +895,20 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 			super(context);
 		}
 
-		public Object getDepthBase()			{ return elem(_depthBase); }
-		public Object getIntersectionGroup()	{ return elem(_intersectionGroup); }
 		public Object getOpacity()				{ return elem(_opacity); }
 		public Object getAudioLevels()			{ return elem(_audioLevels); }
 		public Object getTimeRemap()			{ return LayerNature.isTimeRemapEnabled(AbstractMediaLayer.this) ? elem(_timeRemap) : null; }
 
+		public String getCastsShadows()			{ return _castsShadows.name(); }
+		public Object getLightTransmission()	{ return elem(_lightTransmission); }
+		public boolean isAcceptsShadows()		{ return _acceptsShadows; }
+		public boolean isAcceptsLights()		{ return _acceptsLights; }
+		public Object getAmbient()				{ return elem(_ambient); }
+		public Object getDiffuse()				{ return elem(_diffuse); }
+		public Object getSpecular()				{ return elem(_specular); }
+		public Object getShininess()			{ return elem(_shininess); }
+		public Object getMetal()				{ return elem(_metal); }
+
 		public Object effect(int index) {
 			Effect effect = _effects.get(index - 1);
 			return context.getExpressionElement(effect);
@@ -1043,4 +924,21 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		}
 	}
 
+	public static class AnimatableCastsShadows
+			extends AbstractAnimatableEnum<CastsShadows> {
+
+		public AnimatableCastsShadows(
+				CastsShadows staticValue,
+				Collection<Keyframe<CastsShadows>> keyframes,
+				String expression) {
+		
+			super(CastsShadows.class, staticValue, keyframes, expression);
+		}
+	
+		public AnimatableCastsShadows(CastsShadows staticValue) {
+			super(CastsShadows.class, staticValue);
+		}
+
+	}
+	
 }
