@@ -23,6 +23,8 @@
 
 package ch.kuramo.javie.core.internal;
 
+import java.util.List;
+import java.util.ListIterator;
 import java.util.Map;
 
 import javax.media.opengl.GL2;
@@ -34,11 +36,15 @@ import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.Vec3d;
 import ch.kuramo.javie.core.Camera;
 import ch.kuramo.javie.core.CameraLayer;
+import ch.kuramo.javie.core.Layer;
+import ch.kuramo.javie.core.LayerComposition;
+import ch.kuramo.javie.core.LayerNature;
 import ch.kuramo.javie.core.Util;
-import ch.kuramo.javie.core.WrappedOperation;
 import ch.kuramo.javie.core.services.RenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 
+import com.google.inject.Inject;
+
 class CameraImpl implements Camera {
 
 	private final RenderContext _context;
@@ -58,36 +64,36 @@ class CameraImpl implements Camera {
 	private final Map<Time, double[][]> _matrix3DCache;
 
 
-	CameraImpl(
-			RenderContext context,
-			VideoRenderSupport vrSupport,
-			CameraLayer cameraLayer,
-			Size2i compSize,
-			Size2i viewportSize) {
+	@Inject
+	CameraImpl(RenderContext context, VideoRenderSupport vrSupport) {
+		LayerComposition comp = (LayerComposition) context.getComposition();
 
-		super();
+		// 上のレイヤーから(リスト内では末尾から)順に有効なカメラレイヤーを探し、見つかればそれを使う。
+		CameraLayer cameraLayer = null;
+		List<Layer> layers = comp.getLayers();
+		Time time = context.getTime();
+		for (ListIterator<Layer> it = layers.listIterator(layers.size()); it.hasPrevious(); ) {
+			Layer layer = it.previous();
+			if (layer instanceof CameraLayer && LayerNature.isVideoEnabled(layer)
+					&& !layer.getInPoint().after(time) && layer.getOutPoint().after(time)) {
+				cameraLayer = (CameraLayer) layer;
+				break;
+			}
+		}
 
 		_context = context;
 		_vrSupport = vrSupport;
 		_cameraLayer = cameraLayer;
-		_compSize = compSize;
-
-		_viewportSize = viewportSize;
+		_compSize = comp.getSize();
+		_viewportSize = context.getVideoResolution().scale(_compSize);
 		_mvMatrix2D = new double[16];
 		_prjMatrix2D = new double[16];
 		_matrix3DCache = Util.newMap();
 
 		createMatrix2D();
-
-		// バグ回避するために3Dの行列計算も事前に済ませておく。
-		// （「カメラに親が設定してあり、コラップスしたプリコンポレイヤーが一番下にある」
-		// 　という状況でカメラの親のトランスフォームが反映されない、というバグ）
-		getMatrix3D();
 	}
 
 	private void createMatrix2D() {
-		// TODO この処理は VideoRenderSupport 内に持たすべきでは？
-
 		GL2 gl = _context.getGL().getGL2();
 		GLU glu = _context.getGLU();
 
@@ -128,69 +134,62 @@ class CameraImpl implements Camera {
 			return matrix;
 		}
 
-		matrix = _vrSupport.pushMatrixAndExecute(new WrappedOperation<double[][]>() {
-			public double[][] execute() {
-				Vec3d orientation, rotation, position, pointOfInterest;
-				double fovy, near, far;
-				double aspect = (double) _viewportSize.width / _viewportSize.height;
+		Vec3d orientation, rotation, position, interest;
+		double fovy, near, far;
+		double aspect = (double) _viewportSize.width / _viewportSize.height;
 
-				if (_cameraLayer != null) {
-					orientation = _cameraLayer.getOrientation().value(_context);
-					rotation = new Vec3d(
-							_cameraLayer.getRotationX().value(_context),
-							_cameraLayer.getRotationY().value(_context),
-							_cameraLayer.getRotationZ().value(_context));
-					position = _cameraLayer.getPosition().value(_context);
-					pointOfInterest = _cameraLayer.getPointOfInterest().value(_context);
+		if (_cameraLayer != null) {
+			orientation = _cameraLayer.getOrientation().value(_context);
+			rotation = new Vec3d(
+					_cameraLayer.getRotationX().value(_context),
+					_cameraLayer.getRotationY().value(_context),
+					_cameraLayer.getRotationZ().value(_context));
+			position = _cameraLayer.getPosition().value(_context);
+			interest = _cameraLayer.getPointOfInterest().value(_context);
 
-					double zoom = _cameraLayer.getZoom().value(_context);
-					fovy = Math.toDegrees(2 * Math.atan(_compSize.height / (2*zoom)));
-					near = _cameraLayer.getNear().value(_context);
-					far = _cameraLayer.getFar().value(_context);
+			double zoom = _cameraLayer.getZoom().value(_context);
+			fovy = Math.toDegrees(2 * Math.atan(_compSize.height / (2*zoom)));
+			near = _cameraLayer.getNear().value(_context);
+			far = _cameraLayer.getFar().value(_context);
 
-				} else {
-					double zoom = getDefaultZoom();
-					fovy = Math.toDegrees(2 * Math.atan(_compSize.height / (2*zoom)));
+		} else {
+			double zoom = getDefaultZoom();
+			fovy = Math.toDegrees(2 * Math.atan(_compSize.height / (2*zoom)));
 
-					// TODO デフォルトカメラのニアクリップ面、ファクリップ面はこれで妥当か？
-					near = zoom / 2;
-					far = zoom * 10;
+			near = CameraLayerImpl.DEFAULT_NEAR;
+			far = CameraLayerImpl.DEFAULT_FAR;
 
-					orientation = new Vec3d(0, 0, 0);
-					rotation = new Vec3d(0, 0, 0);
-					position = new Vec3d(_compSize.width/2.0, _compSize.height/2.0, -zoom);
-					pointOfInterest = new Vec3d(position.x, position.y, 0);
-				}
+			orientation = new Vec3d(0, 0, 0);
+			rotation = new Vec3d(0, 0, 0);
+			position = new Vec3d(_compSize.width/2.0, _compSize.height/2.0, -zoom);
+			interest = new Vec3d(position.x, position.y, 0);
+		}
 
-				Resolution resolution = _context.getVideoResolution();
-				position = resolution.scale(position);
-				pointOfInterest = resolution.scale(pointOfInterest);
-				near = resolution.scale(near);
-				far = resolution.scale(far);
+		Resolution resolution = _context.getVideoResolution();
+		position = resolution.scale(position);
+		interest = resolution.scale(interest);
+		near = resolution.scale(near);
+		far = resolution.scale(far);
 
 
-				GL2 gl = _context.getGL().getGL2();
-				GLU glu = _context.getGLU();
+		GL2 gl = _context.getGL().getGL2();
+		GLU glu = _context.getGLU();
 
-				gl.glMatrixMode(GL2.GL_PROJECTION);
-				gl.glLoadIdentity();
-				glu.gluPerspective(fovy, aspect, near, far);
+		gl.glMatrixMode(GL2.GL_PROJECTION);
+		gl.glLoadIdentity();
+		glu.gluPerspective(fovy, aspect, near, far);
 
-				gl.glMatrixMode(GL2.GL_MODELVIEW);
-				gl.glLoadIdentity();
+		gl.glMatrixMode(GL2.GL_MODELVIEW);
+		gl.glLoadIdentity();
 
-				_vrSupport.multCameraMatrix(orientation, rotation, position, pointOfInterest, true);
+		_vrSupport.multCameraMatrix(rotation, orientation, interest, position, true);
 
-				if (_cameraLayer != null) {
-					LayerMatrixUtil.multParentMatrix(_cameraLayer, _context, _vrSupport);
-				}
+		if (_cameraLayer != null) {
+			LayerMatrixUtil.multParentMatrix(_cameraLayer, _context, _vrSupport);
+		}
 
-				double[][] matrix3D = new double[2][16];
-				_vrSupport.getMatrix(matrix3D[0], matrix3D[1]);
-
-				return matrix3D;
-			}
-		});
+		matrix = new double[2][16];
+		_vrSupport.getMatrix(matrix[0], matrix[1]);
 
 		_matrix3DCache.put(time, matrix);
 		return matrix;
@@ -204,11 +203,6 @@ class CameraImpl implements Camera {
 		return _compSize.width / (2 * Math.tan(Math.toRadians(fovx/2)));
 	}
 
-	public Vec3d getPosition() {
-		return (_cameraLayer != null) ? _cameraLayer.getPosition().value(_context)
-				: new Vec3d(_compSize.width/2.0, _compSize.height/2.0, -getDefaultZoom());
-	}
-
 	public void getModelViewMatrix(double[] matrix) {
 		System.arraycopy(getModelView3D(), 0, matrix, 0, 16);
 	}
