@@ -29,35 +29,34 @@ import java.util.ListIterator;
 import ch.kuramo.javie.api.ColorMode;
 import ch.kuramo.javie.api.IAudioBuffer;
 import ch.kuramo.javie.api.IVideoBuffer;
-import ch.kuramo.javie.api.Size2i;
 import ch.kuramo.javie.api.Time;
-import ch.kuramo.javie.api.Vec3d;
 import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.core.AbstractComposition;
-import ch.kuramo.javie.core.CameraLayer;
-import ch.kuramo.javie.core.CollapseTransformation;
 import ch.kuramo.javie.core.CoreContext;
 import ch.kuramo.javie.core.ExpressionScope;
 import ch.kuramo.javie.core.Layer;
 import ch.kuramo.javie.core.LayerComposition;
 import ch.kuramo.javie.core.LayerNature;
-import ch.kuramo.javie.core.MediaInput;
+import ch.kuramo.javie.core.MediaItemLayer;
 import ch.kuramo.javie.core.MediaLayer;
-import ch.kuramo.javie.core.MotionBlur;
 import ch.kuramo.javie.core.Project;
 import ch.kuramo.javie.core.ProjectDecodeException;
+import ch.kuramo.javie.core.SuperSampling;
 import ch.kuramo.javie.core.TrackMatte;
 import ch.kuramo.javie.core.Util;
-import ch.kuramo.javie.core.VideoLayerBuffer;
-import ch.kuramo.javie.core.VideoLayerComposer;
 import ch.kuramo.javie.core.VideoLayerRenderer;
 import ch.kuramo.javie.core.WrappedOperation;
+import ch.kuramo.javie.core.VideoLayerRenderer.AbstractMatteLayerRenderers;
+import ch.kuramo.javie.core.VideoLayerRenderer.CRLayerRenderer;
+import ch.kuramo.javie.core.VideoLayerRenderer.GeneralLayerRenderer;
+import ch.kuramo.javie.core.VideoLayerRenderer.MatteLayerRenderers;
+import ch.kuramo.javie.core.VideoLayerRenderer.NormalLayerRenderer;
 import ch.kuramo.javie.core.annotations.ProjectElement;
 import ch.kuramo.javie.core.services.AudioRenderSupport;
 import ch.kuramo.javie.core.services.RenderContext;
-import ch.kuramo.javie.core.services.VideoRenderSupport;
 
 import com.google.inject.Inject;
+import com.google.inject.Injector;
 
 @ProjectElement("layerComposition")
 public class LayerCompositionImpl extends AbstractComposition implements LayerComposition {
@@ -74,11 +73,7 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 
 	private int _motionBlurSamples = 16;
 
-	private final MotionBlur _motionBlur = new MotionBlur() {
-		public double getShutterAngle()	{ return _motionBlurShutterAngle; }
-		public double getShutterPhase()	{ return _motionBlurShutterPhase; }
-		public int getSamples()			{ return _motionBlurSamples; }
-	};
+	private SuperSampling _superSampling = SuperSampling.SS_NONE;
 
 	private List<Layer> _layers = Util.newList();
 
@@ -86,10 +81,10 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 	private RenderContext _context;
 
 	@Inject
-	private VideoRenderSupport _vrSupport;
+	private AudioRenderSupport _arSupport;
 
 	@Inject
-	private AudioRenderSupport _arSupport;
+	private Injector _injector;
 
 
 	public LayerCompositionImpl() {
@@ -144,6 +139,14 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 		_motionBlurSamples = motionBlurSamples;
 	}
 
+	public SuperSampling getSuperSampling() {
+		return _superSampling;
+	}
+
+	public void setSuperSampling(SuperSampling superSampling) {
+		_superSampling = superSampling;
+	}
+
 	public List<Layer> getLayers() {
 		return _layers;
 	}
@@ -200,28 +203,10 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 			_context.setVideoFrameDuration(frameDuration);
 		}
 
-		// 上のレイヤーから(リスト内では末尾から)順に有効なカメラレイヤーを探し、見つかればそれを使う。
-		CameraLayer cameraLayer = null;
-		for (ListIterator<Layer> it = _layers.listIterator(_layers.size()); it.hasPrevious(); ) {
-			Layer layer = it.previous();
-			if (layer instanceof CameraLayer && LayerNature.isVideoEnabled(layer)
-					&& !layer.getInPoint().after(time) && layer.getOutPoint().after(time)) {
-				cameraLayer = (CameraLayer) layer;
-				break;
-			}
-		}
+		_context.setCamera(_injector.getInstance(CameraImpl.class));
+		_context.setLights(_injector.getInstance(LightSet.class).getLights());
 
-		Size2i renderSize = _context.getVideoResolution().scale(getSize());
-
-		CameraImpl camera = new CameraImpl(
-				_context, _vrSupport, cameraLayer, getSize(), renderSize);
-
-		_context.setCamera(camera);
-
-		final VideoLayerComposerImpl composer = new VideoLayerComposerImpl(
-				_context, _vrSupport, colorMode, renderSize, camera.getPosition());
-
-		final MotionBlur motionBlur = _motionBlurEnabled ? _motionBlur : null;
+		VideoLayerComposer composer = _injector.getInstance(VideoLayerComposer.class);
 
 		for (int i = 0, n = _layers.size(); i < n; ++i) {
 			Layer layer = _layers.get(i);
@@ -235,30 +220,25 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 			}
 
 			if (layer instanceof MediaLayer) {
-				final MediaLayer ml = (MediaLayer) layer;
+				MediaLayer mediaLayer = (MediaLayer) layer;
+				MediaLayer matteLayer = null;
 
-				if (ml.getTrackMatte() != TrackMatte.NONE && i+1 < n) {
-					Layer matteLayer = _layers.get(i+1);
-					if (matteLayer instanceof MediaLayer) {
-						setupTrackMatteRenderer(ml, (MediaLayer) matteLayer, composer, null, motionBlur);
-						continue;
+				if (mediaLayer.getTrackMatte() != TrackMatte.NONE && i+1 < n) {
+					Layer nextLayer = _layers.get(i+1);
+					if (nextLayer instanceof MediaLayer) {
+						matteLayer = (MediaLayer) nextLayer;
 					}
 				}
 
-				_context.saveAndExecute(new WrappedOperation<Object>() {
-					public Object execute() {
-						ml.setupVideoRenderer(composer, null, motionBlur, _frameBlendEnabled, true, true);
-						return null;
-					}
-				});
+				composer.addLayerRenderers(createVideoRenderers(mediaLayer, matteLayer));
 			}
 		}
 
 		return composer.compose();
 	}
 
-	public void setupCollapseTransformation(
-			final VideoLayerComposer composer, final CollapseTransformation ct, final MotionBlur motionBlur) {
+	public List<VideoLayerRenderer> createCollapsedRenderers() {
+		List<VideoLayerRenderer> list = Util.newList();
 
 		_context.setComposition(this);
 
@@ -276,114 +256,75 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 			}
 
 			if (layer instanceof MediaLayer) {
-				final MediaLayer ml = (MediaLayer) layer;
+				MediaLayer mediaLayer = (MediaLayer) layer;
+				MediaLayer matteLayer = null;
 
-				if (ml.getTrackMatte() != TrackMatte.NONE && i+1 < n) {
-					Layer matteLayer = _layers.get(i+1);
-					if (matteLayer instanceof MediaLayer) {
-						setupTrackMatteRenderer(ml, (MediaLayer) matteLayer, composer, ct, motionBlur);
-						continue;
+				if (mediaLayer.getTrackMatte() != TrackMatte.NONE && i+1 < n) {
+					Layer nextLayer = _layers.get(i+1);
+					if (nextLayer instanceof MediaLayer) {
+						matteLayer = (MediaLayer) nextLayer;
 					}
 				}
 
-				_context.saveAndExecute(new WrappedOperation<Object>() {
-					public Object execute() {
-						ml.setupVideoRenderer(composer, ct, motionBlur, _frameBlendEnabled, true, true);
-						return null;
+				list.addAll(createVideoRenderers(mediaLayer, matteLayer));
+			}
+		}
+
+		return list;
+	}
+
+	private List<VideoLayerRenderer> createVideoRenderers(final MediaLayer layer, MediaLayer matteLayer) {
+		List<VideoLayerRenderer> renderers = null;
+
+		if (layer instanceof MediaItemLayer) {
+			final MediaItemLayer miLayer = (MediaItemLayer) layer;
+
+			if (LayerNature.isCTCR(miLayer) && miLayer.isPrecompositionLayer()) {
+				renderers = _context.saveAndExecute(new WrappedOperation<List<VideoLayerRenderer>>() {
+					public List<VideoLayerRenderer> execute() {
+						return miLayer.createCollapsedRenderers();
 					}
 				});
 			}
 		}
-	}
 
-	private void setupTrackMatteRenderer(
-			final MediaLayer fillLayer, final MediaLayer matteLayer,
-			VideoLayerComposer composer, final CollapseTransformation ct, final MotionBlur motionBlur) {
+		if (renderers == null) {
+			GeneralLayerRenderer r = _context.saveAndExecute(new WrappedOperation<GeneralLayerRenderer>() {
+				public GeneralLayerRenderer execute() {
+					return layer.createVideoRenderer();
+				}
+			});
 
-		final VideoLayerRenderer[] renderers = new VideoLayerRenderer[2];
-		final Vec3d[][] vertices = new Vec3d[1][];
-		final String[] intersectionGroup = new String[1];
-
-		_context.saveAndExecute(new WrappedOperation<Object>() {
-			public Object execute() {
-				fillLayer.setupVideoRenderer(new VideoLayerComposer() {
-					public void add2D(VideoLayerRenderer r)							{ renderers[0] = r; }
-					public void add3D(VideoLayerRenderer r, Vec3d[] v, String ig)	{ renderers[0] = r; vertices[0] = v; intersectionGroup[0] = ig; }
-				}, ct, motionBlur, _frameBlendEnabled, true, true);
-				return null;
+			// このリストは、コラップスした場合にListIterator経由でsetされるので、
+			// Collections.singletonList/emptyList を使ってはいけない。
+			renderers = Util.newList();
+			if (r != null) {
+				renderers.add(r);
 			}
-		});
-
-		_context.saveAndExecute(new WrappedOperation<Object>() {
-			public Object execute() {
-				matteLayer.setupVideoRenderer(new VideoLayerComposer() {
-					public void add2D(VideoLayerRenderer r)							{ renderers[1] = r; }
-					public void add3D(VideoLayerRenderer r, Vec3d[] v, String ig)	{ renderers[1] = r; }
-				}, ct, motionBlur, _frameBlendEnabled, true, true);
-				return null;
-			}
-		});
-
-
-		if (renderers[0] == null) {
-			return;
-
-		} else if (renderers[1] == null) {
-			if (vertices[0] == null) {
-				composer.add2D(renderers[0]);
-			} else {
-				composer.add3D(renderers[0], vertices[0], intersectionGroup[0]);
-			}
-			return;
 		}
 
+		if (!renderers.isEmpty() && matteLayer != null) {
+			final List<VideoLayerRenderer> matteRenderers = createVideoRenderers(matteLayer, null);
+			if (!matteRenderers.isEmpty()) {
+				MatteLayerRenderers mlr = new AbstractMatteLayerRenderers() {
+					public MediaLayer getLayer() { return layer; }
+					public List<VideoLayerRenderer> getRenderers() { return matteRenderers; }
+				};
 
-		final TrackMatte trackMatte = fillLayer.getTrackMatte();
-
-		VideoLayerRenderer r = new VideoLayerRenderer() {
-			public VideoLayerBuffer render(boolean withDepthBuffer) {
-				VideoLayerBuffer fillBuffer = null;
-				VideoLayerBuffer matteBuffer = null;
-				IVideoBuffer vbFill = null;
-				try {
-					fillBuffer = renderers[0].render(withDepthBuffer);
-					matteBuffer = renderers[1].render(false);
-					vbFill = fillBuffer.getVideoBuffer();
-
-					IVideoBuffer resultBuffer = _vrSupport.createVideoBuffer(vbFill.getColorMode(), vbFill.getBounds());
-					_vrSupport.trackMatte(matteBuffer.getVideoBuffer(), fillBuffer.getVideoBuffer(), resultBuffer,
-							trackMatte, matteBuffer.getOpacity());
-
-					VideoLayerBuffer newBuffer = new VideoLayerBufferImpl(
-							resultBuffer, fillBuffer.getDepthBuffer(),
-							fillBuffer.getBlendMode(), fillBuffer.getOpacity(), fillBuffer.getDissolveSeed());
-					fillBuffer = null;
-					return newBuffer;
-
-				} finally {
-					if (matteBuffer != null) {
-						matteBuffer.dispose();
-					}
-
-					// 正常時はfillBufferを破棄してしまうとDepthBufferまで破棄されてしまうので、IVideoBufferだけ破棄する。
-					// (tryブロックを抜ける直前にfillBufferにnullを代入しているので、ここでfillBufferがnullでないのは例外発生時のみ)
-					if (fillBuffer != null) {
-						fillBuffer.dispose();
-					} else if (vbFill != null) {
-						vbFill.dispose();
+				for (VideoLayerRenderer r : renderers) {
+					if (r instanceof GeneralLayerRenderer) {
+						((GeneralLayerRenderer) r).addMatteId(mlr.getMatteId());
 					}
 				}
-			}
-		};
 
-		if (vertices[0] == null) {
-			composer.add2D(r);
-		} else {
-			composer.add3D(r, vertices[0], intersectionGroup[0]);
+				renderers.add(mlr);
+			}
 		}
+
+		return renderers;
 	}
 
-	public IVideoBuffer getLayerVideoFrame(Layer layer, final boolean withEffects, final boolean withTransformation) {
+	public IVideoBuffer getLayerVideoFrame(Layer layer, boolean rawSource) {
 		if (_context.getComposition() != this) {
 			throw new IllegalStateException("this composition is not the context composition.");
 		}
@@ -400,47 +341,58 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 			return null;
 		}
 
-		if (layer instanceof MediaLayer) {
-			final MediaLayer ml = (MediaLayer) layer;
-
-			MediaInput input = ml.getMediaInput();
-			if (input == null) {
+		if (rawSource) {
+			if (layer instanceof MediaLayer) {
+				final MediaLayer ml = (MediaLayer) layer;
+				
+				return _context.saveAndExecute(new WrappedOperation<IVideoBuffer>() {
+					public IVideoBuffer execute() {
+						GeneralLayerRenderer r = ml.createVideoRenderer();
+						if (r instanceof NormalLayerRenderer) {
+							return ((NormalLayerRenderer) r).render(false, _frameBlendEnabled);
+						} else {
+							CameraImpl camera = _injector.getInstance(CameraImpl.class);
+							return ((CRLayerRenderer) r).render(false, new VideoBounds(camera.getViewportSize()),
+														camera.getModelView2D(), camera.getProjection2D());
+						}
+					}
+				});				
+			}
+		} else {
+			Time time = _context.getTime();
+			if (layer.getInPoint().after(time) || !layer.getOutPoint().after(time)) {
 				return null;
 			}
 
-			VideoBounds bounds = input.getVideoFrameBounds();
-			final Size2i layerSize = LayerNature.isCTCR(layer) ? getSize() : new Size2i(bounds.width, bounds.height);
-			final Size2i viewportSize = _context.getVideoResolution().scale(layerSize);
+			if (layer instanceof MediaItemLayer) {
+				final MediaItemLayer miLayer = (MediaItemLayer) layer;
 
-			if (viewportSize.width == 0 || viewportSize.height == 0) {
-				IVideoBuffer vb = _vrSupport.createVideoBuffer(_context.getColorMode(), viewportSize);
-				vb.clear();
-				return vb;
+				if (LayerNature.isCTCR(miLayer) && miLayer.isPrecompositionLayer()) {
+					return _context.saveAndExecute(new WrappedOperation<IVideoBuffer>() {
+						public IVideoBuffer execute() {
+							_context.setCamera(_injector.getInstance(CameraImpl.class));
+
+							VideoLayerComposer composer = _injector.getInstance(VideoLayerComposer.class);
+							composer.addLayerRenderers(miLayer.createCollapsedRenderers());
+							return composer.compose();
+						}
+					});
+				}
 			}
 
-			final VideoLayerRenderer[] renderers = new VideoLayerRenderer[1];
+			if (layer instanceof MediaLayer) {
+				final MediaLayer ml = (MediaLayer) layer;
 
-			final VideoLayerComposer composer = new VideoLayerComposer() {
-				public void add2D(VideoLayerRenderer r)							{ renderers[0] = r; }
-				public void add3D(VideoLayerRenderer r, Vec3d[] v, String ig)	{ renderers[0] = r; }
-			};
+				return _context.saveAndExecute(new WrappedOperation<IVideoBuffer>() {
+					public IVideoBuffer execute() {
+						_context.setCamera(_injector.getInstance(CameraImpl.class));
 
-			final MotionBlur motionBlur = _motionBlurEnabled ? _motionBlur : null;
-
-			_context.saveAndExecute(new WrappedOperation<Object>() {
-				public Object execute() {
-					_context.setCamera(new CameraImpl(
-							_context, _vrSupport, null, layerSize, viewportSize));
-
-					ml.setupVideoRenderer(
-							composer, null, motionBlur, _frameBlendEnabled,
-							withEffects, withTransformation);
-					return null;
-				}
-			});
-
-			VideoLayerBuffer vlb = renderers[0].render(false);
-			return vlb.getVideoBuffer();
+						VideoLayerComposer composer = _injector.getInstance(VideoLayerComposer.class);
+						composer.addLayerRenderer(ml.createVideoRenderer());
+						return composer.compose();
+					}
+				});
+			}
 		}
 
 		return null;
@@ -475,7 +427,7 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 
 				IAudioBuffer alab = _context.saveAndExecute(new WrappedOperation<IAudioBuffer>() {
 					public IAudioBuffer execute() {
-						return al.renderAudioChunk(true, true);
+						return al.renderAudioChunk(false);
 					}
 				});
 
@@ -502,7 +454,7 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 		return ab;
 	}
 
-	public IAudioBuffer getLayerAudioChunk(Layer layer, final boolean withEffects, final boolean withLevelsAndInOut) {
+	public IAudioBuffer getLayerAudioChunk(Layer layer, final boolean rawSource) {
 		if (_context.getComposition() != this) {
 			throw new IllegalStateException("this composition is not the context composition.");
 		}
@@ -519,17 +471,21 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 			return null;
 		}
 
+		if (!rawSource) {
+			Time time = _context.getTime();
+			Time chunkDuration = Time.fromFrameNumber(
+					_context.getAudioFrameCount(), _context.getAudioMode().sampleDuration);
+			if (layer.getInPoint().after(time.add(chunkDuration)) || !layer.getOutPoint().after(time)) {
+				return null;
+			}
+		}
+
 		if (layer instanceof MediaLayer) {
 			final MediaLayer ml = (MediaLayer) layer;
 
-			MediaInput input = ml.getMediaInput();
-			if (input == null) {
-				return null;
-			}
-
 			return _context.saveAndExecute(new WrappedOperation<IAudioBuffer>() {
 				public IAudioBuffer execute() {
-					return ml.renderAudioChunk(withEffects, withLevelsAndInOut);
+					return ml.renderAudioChunk(rawSource);
 				}
 			});
 		}
@@ -564,11 +520,11 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 			return null;
 		}
 
-		public int getHeight() {
+		public int getWidth() {
 			return getSize().width;
 		}
 
-		public int getWidth() {
+		public int getHeight() {
 			return getSize().height;
 		}
 
