@@ -29,9 +29,9 @@ import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.Resolution;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.VideoBounds;
+import ch.kuramo.javie.api.services.IVideoRenderSupport;
 import ch.kuramo.javie.core.MediaInputPlaceholder;
 import ch.kuramo.javie.core.services.RenderContext;
-import ch.kuramo.javie.core.services.VideoRenderSupport;
 
 import com.google.inject.Inject;
 
@@ -39,14 +39,14 @@ class MediaInputPlaceholderImpl implements MediaInputPlaceholder {
 
 	private final RenderContext _context;
 
-	private final VideoRenderSupport _vrSupport;
+	private final IVideoRenderSupport _support;
 
 	private VideoBounds videoFrameBounds;
 
 	@Inject
-	MediaInputPlaceholderImpl(RenderContext context, VideoRenderSupport vrSupport) {
+	MediaInputPlaceholderImpl(RenderContext context, IVideoRenderSupport support) {
 		_context = context;
-		_vrSupport = vrSupport;
+		_support = support;
 	}
 
 	public boolean isAudioAvailable() {
@@ -81,7 +81,7 @@ class MediaInputPlaceholderImpl implements MediaInputPlaceholder {
 		Resolution resolution = _context.getVideoResolution();
 		VideoBounds bounds = resolution.scale(getVideoFrameBounds());
 
-		IVideoBuffer videoBuffer = _vrSupport.createVideoBuffer(_context.getColorMode(), bounds);
+		IVideoBuffer videoBuffer = _support.createVideoBuffer(bounds);
 		videoBuffer.clear(Color.GRAY);
 
 		return videoBuffer;
