@@ -25,12 +25,12 @@ package ch.kuramo.javie.core.internal;
 
 import net.arnx.jsonic.JSONHint;
 import ch.kuramo.javie.api.Color;
-import ch.kuramo.javie.api.ColorMode;
 import ch.kuramo.javie.api.IAudioBuffer;
 import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.Size2i;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.VideoBounds;
+import ch.kuramo.javie.api.services.IVideoRenderSupport;
 import ch.kuramo.javie.core.AbstractItem;
 import ch.kuramo.javie.core.MediaInput;
 import ch.kuramo.javie.core.MediaOptions;
@@ -58,7 +58,10 @@ public class SolidColorItemImpl extends AbstractItem implements SolidColorItem {
 	private RenderContext _context;
 
 	@Inject
-	private VideoRenderSupport _vrSupport;
+	private IVideoRenderSupport _support;
+
+	@Inject
+	private VideoRenderSupport _oldSupport;
 
 
 	public SolidColorItemImpl() {
@@ -146,10 +149,9 @@ public class SolidColorItemImpl extends AbstractItem implements SolidColorItem {
 		}
 
 		public IVideoBuffer getVideoFrame(Time mediaTime) {
-			ColorMode colorMode = _context.getColorMode();
 			Size2i size = _context.getVideoResolution().scale(_size);
 
-			IVideoBuffer vb = _vrSupport.createVideoBuffer(colorMode, size);
+			IVideoBuffer vb = _support.createVideoBuffer(new VideoBounds(size));
 			vb.clear(_color);
 
 			return vb;
@@ -157,7 +159,7 @@ public class SolidColorItemImpl extends AbstractItem implements SolidColorItem {
 
 		public void rasterize(IVideoBuffer resultBuffer, double[] mvMatrix, double[] prjMatrix, Time mediaTime) {
 			Size2i size = _context.getVideoResolution().scale(_size);
-			_vrSupport.fillRectCR(resultBuffer, mvMatrix, prjMatrix, size, _color);
+			_oldSupport.fillRectCR(resultBuffer, mvMatrix, prjMatrix, size, _color);
 		}
 
 		public IAudioBuffer getAudioChunk(Time mediaTime) {
