@@ -33,6 +33,7 @@ import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.Resolution;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.VideoBounds;
+import ch.kuramo.javie.api.services.IVideoRenderSupport;
 import ch.kuramo.javie.core.AbstractAnimatableEnum;
 import ch.kuramo.javie.core.AnimatableColor;
 import ch.kuramo.javie.core.AnimatableDouble;
@@ -81,7 +82,10 @@ public class TextLayerImpl extends AbstractMediaLayer implements TextLayer {
 	private RenderContext _context;
 
 	@Inject
-	private VideoRenderSupport _vrSupport;
+	private IVideoRenderSupport _support;
+
+	@Inject
+	private VideoRenderSupport _oldSupport;
 
 	@Inject
 	private FontList _fontList;
@@ -234,10 +238,34 @@ public class TextLayerImpl extends AbstractMediaLayer implements TextLayer {
 				return null;
 			}
 
+			if (!_ctcr) {
+				return getBounds(false);
+			}
+
+			switch (getCastsShadows()) {
+				case OFF:
+					return getBounds(true);
+
+				case ONLY:
+					return getBounds(false);
+
+				//case ON:
+				default:
+					VideoBounds b1 = getBounds(true);
+					VideoBounds b2 = getBounds(false);
+					double left = Math.min(b1.x, b2.x);
+					double top = Math.min(b1.y, b2.y);
+					double right = Math.max(b1.x+b1.width, b2.x+b2.width);
+					double bottom = Math.max(b1.y+b1.height, b2.y+b2.height);
+					return new VideoBounds(left, top, (int)Math.ceil(right-left), (int)Math.ceil(bottom-top));
+			}
+		}
+
+		private VideoBounds getBounds(boolean polygonFont) {
 			String sourceText = _sourceText.value(_context);
 			String psName = _font.value(_context);
 			int fontSize = _fontSize.value(_context);
-			FTGLfont font = getFont(psName, fontSize);
+			FTGLfont font = getFont(psName, fontSize, polygonFont);
 
 			if (sourceText.length() == 0 || font == null) {
 				return new VideoBounds(0, 0);
@@ -291,12 +319,12 @@ public class TextLayerImpl extends AbstractMediaLayer implements TextLayer {
 			Resolution resolution = _context.getVideoResolution();
 			VideoBounds bounds = resolution.scale(getVideoFrameBounds());
 
-			IVideoBuffer vb = _vrSupport.createVideoBuffer(_context.getColorMode(), bounds);
+			IVideoBuffer vb = _support.createVideoBuffer(bounds);
 			vb.clear();
 
 			String psName = _font.value(_context);
 			int fontSize = _fontSize.value(_context);
-			FTGLfont font = getFont(psName, fontSize);
+			FTGLfont font = getFont(psName, fontSize, false);
 			if (font != null) {
 				String sourceText = _sourceText.value(_context);
 				Color fillColor = _fillColor.value(_context);
@@ -310,7 +338,7 @@ public class TextLayerImpl extends AbstractMediaLayer implements TextLayer {
 
 				double[][] offsets = calcTextOffsets(font, texts, halign, leading, resolution);
 
-				_vrSupport.renderText(font, fillColor, texts, offsets, vb);
+				_oldSupport.renderText(font, fillColor, texts, offsets, vb);
 			}
 
 			return vb;
@@ -321,7 +349,7 @@ public class TextLayerImpl extends AbstractMediaLayer implements TextLayer {
 
 			String psName = _font.value(_context);
 			int fontSize = _fontSize.value(_context);
-			FTGLfont font = getFont(psName, fontSize);
+			FTGLfont font = getFont(psName, fontSize, true);
 			if (font != null) {
 				String sourceText = _sourceText.value(_context);
 				Color fillColor = _fillColor.value(_context);
@@ -335,12 +363,12 @@ public class TextLayerImpl extends AbstractMediaLayer implements TextLayer {
 
 				double[][] offsets = calcTextOffsets(font, texts, halign, leading, resolution);
 
-				_vrSupport.renderText(
+				_oldSupport.renderText(
 						font, fillColor, texts, offsets, resultBuffer, mvMatrix, prjMatrix);
 			}
 		}
 
-		private FTGLfont getFont(String psName, int fontSize) {
+		private FTGLfont getFont(String psName, int fontSize, boolean polygonFont) {
 			Font font = _fontList.get(psName);
 			if (font == null && (font = _fontList.defaultFont()) == null) {
 				return null;
@@ -349,7 +377,7 @@ public class TextLayerImpl extends AbstractMediaLayer implements TextLayer {
 			String fontPath = font.fontFile.getAbsolutePath();
 			int faceIndex = font.faceIndex;
 
-			if (_ctcr) {
+			if (polygonFont) {
 				return _fontManager.getPolygonFont(fontPath, faceIndex, fontSize);
 			} else {
 				return _fontManager.getBufferFont(fontPath, faceIndex, fontSize);
