@@ -36,6 +36,7 @@ import ch.kuramo.javie.api.Resolution;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.api.services.IEffectContext;
+import ch.kuramo.javie.api.services.IVideoRenderSupport;
 import ch.kuramo.javie.core.AnimatableValue;
 import ch.kuramo.javie.core.Composition;
 import ch.kuramo.javie.core.Layer;
@@ -43,18 +44,17 @@ import ch.kuramo.javie.core.LayerComposition;
 import ch.kuramo.javie.core.WrappedOperation;
 import ch.kuramo.javie.core.services.AudioRenderSupport;
 import ch.kuramo.javie.core.services.RenderContext;
-import ch.kuramo.javie.core.services.VideoRenderSupport;
 
 public abstract class AbstractEffectContext implements IEffectContext {
 
 	private final RenderContext _context;
 
-	private final VideoRenderSupport _vrSupport;
+	private final IVideoRenderSupport _vrSupport;
 
 	private final AudioRenderSupport _arSupport;
 
 
-	public AbstractEffectContext(RenderContext context, VideoRenderSupport vrSupport, AudioRenderSupport arSupport) {
+	public AbstractEffectContext(RenderContext context, IVideoRenderSupport vrSupport, AudioRenderSupport arSupport) {
 		super();
 		_context = context;
 		_vrSupport = vrSupport;
@@ -99,7 +99,7 @@ public abstract class AbstractEffectContext implements IEffectContext {
 	}
 
 	public IVideoBuffer createVideoBuffer(VideoBounds bounds) {
-		return _vrSupport.createVideoBuffer(_context.getColorMode(), bounds);
+		return _vrSupport.createVideoBuffer(bounds);
 	}
 
 
@@ -128,7 +128,7 @@ public abstract class AbstractEffectContext implements IEffectContext {
 
 		return _context.saveAndExecute(new WrappedOperation<IVideoBuffer>() {
 			public IVideoBuffer execute() {
-				return layerComp.getLayerVideoFrame(layer, false, false);
+				return layerComp.getLayerVideoFrame(layer, true);
 			}
 		});
 	}
@@ -148,7 +148,7 @@ public abstract class AbstractEffectContext implements IEffectContext {
 
 		return _context.saveAndExecute(new WrappedOperation<IAudioBuffer>() {
 			public IAudioBuffer execute() {
-				return layerComp.getLayerAudioChunk(layer, false, false);
+				return layerComp.getLayerAudioChunk(layer, true);
 			}
 		});
 	}
