@@ -133,7 +133,6 @@ public class AntiAliasSupportImpl implements IAntiAliasSupport {
 		}
 
 		if (clearColor != null) {
-			clearColor = clearColor.clamp();
 			float a = (float)clearColor.a;
 			float r = (float)clearColor.r * a;
 			float g = (float)clearColor.g * a;
@@ -215,7 +214,7 @@ public class AntiAliasSupportImpl implements IAntiAliasSupport {
 			if (depthTest) {
 				depthTexture = createDepthTexture(gl, width, height);
 				gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
-						GL2.GL_DEPTH_ATTACHMENT, GL2.GL_TEXTURE_RECTANGLE, depthTexture, 0);
+						GL2.GL_DEPTH_ATTACHMENT, GL2.GL_TEXTURE_2D, depthTexture, 0);
 				gl.glEnable(GL2.GL_DEPTH_TEST);
 			}
 
@@ -225,7 +224,7 @@ public class AntiAliasSupportImpl implements IAntiAliasSupport {
 		} finally {
 			if (depthTest) {
 				gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
-						GL2.GL_DEPTH_ATTACHMENT, GL2.GL_TEXTURE_RECTANGLE, 0, 0);
+						GL2.GL_DEPTH_ATTACHMENT, GL2.GL_TEXTURE_2D, 0, 0);
 				if (depthTexture != 0) gl.glDeleteTextures(1, new int[] { depthTexture }, 0);
 			}
 			gl.glPopAttrib();
@@ -241,17 +240,17 @@ public class AntiAliasSupportImpl implements IAntiAliasSupport {
 
 		int[] texture = new int[1];
 		int[] current = new int[1];
-		gl.glGetIntegerv(GL2.GL_TEXTURE_BINDING_RECTANGLE, current, 0);
+		gl.glGetIntegerv(GL2.GL_TEXTURE_BINDING_2D, current, 0);
 		try {
 			gl.glGenTextures(1, texture, 0);
-			gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, texture[0]);
+			gl.glBindTexture(GL2.GL_TEXTURE_2D, texture[0]);
 
-			gl.glTexParameteri(GL2.GL_TEXTURE_RECTANGLE, GL2.GL_TEXTURE_MIN_FILTER, GL2.GL_NEAREST);
-			gl.glTexParameteri(GL2.GL_TEXTURE_RECTANGLE, GL2.GL_TEXTURE_MAG_FILTER, GL2.GL_NEAREST);
-			gl.glTexParameteri(GL2.GL_TEXTURE_RECTANGLE, GL2.GL_TEXTURE_WRAP_S, GL2.GL_CLAMP_TO_BORDER);
-			gl.glTexParameteri(GL2.GL_TEXTURE_RECTANGLE, GL2.GL_TEXTURE_WRAP_T, GL2.GL_CLAMP_TO_BORDER);
-			gl.glTexParameterfv(GL2.GL_TEXTURE_RECTANGLE, GL2.GL_TEXTURE_BORDER_COLOR, FLOAT0000, 0);
-			gl.glTexImage2D(GL2.GL_TEXTURE_RECTANGLE, 0, internalFormat,
+			gl.glTexParameteri(GL2.GL_TEXTURE_2D, GL2.GL_TEXTURE_MIN_FILTER, GL2.GL_NEAREST);
+			gl.glTexParameteri(GL2.GL_TEXTURE_2D, GL2.GL_TEXTURE_MAG_FILTER, GL2.GL_NEAREST);
+			gl.glTexParameteri(GL2.GL_TEXTURE_2D, GL2.GL_TEXTURE_WRAP_S, GL2.GL_CLAMP_TO_BORDER);
+			gl.glTexParameteri(GL2.GL_TEXTURE_2D, GL2.GL_TEXTURE_WRAP_T, GL2.GL_CLAMP_TO_BORDER);
+			gl.glTexParameterfv(GL2.GL_TEXTURE_2D, GL2.GL_TEXTURE_BORDER_COLOR, FLOAT0000, 0);
+			gl.glTexImage2D(GL2.GL_TEXTURE_2D, 0, internalFormat,
 					Math.max(1, width), Math.max(1, height), 0, GL2.GL_DEPTH_COMPONENT, GL2.GL_FLOAT, null);
 
 			int result = texture[0];
@@ -259,7 +258,7 @@ public class AntiAliasSupportImpl implements IAntiAliasSupport {
 			return result;
 
 		} finally {
-			gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, current[0]);
+			gl.glBindTexture(GL2.GL_TEXTURE_2D, current[0]);
 			if (texture[0] != 0) gl.glDeleteTextures(1, texture, 0);
 		}
 	}
