@@ -30,6 +30,7 @@ import ch.kuramo.javie.api.IAudioBuffer;
 import ch.kuramo.javie.api.IObjectArray;
 import ch.kuramo.javie.api.services.IArrayPools;
 import ch.kuramo.javie.api.services.IAudioEffectContext;
+import ch.kuramo.javie.api.services.IVideoRenderSupport;
 import ch.kuramo.javie.core.AnimatableValue;
 import ch.kuramo.javie.core.AudioEffect;
 import ch.kuramo.javie.core.Effect;
@@ -38,7 +39,6 @@ import ch.kuramo.javie.core.WrappedOperation;
 import ch.kuramo.javie.core.services.AudioEffectPipeline;
 import ch.kuramo.javie.core.services.AudioRenderSupport;
 import ch.kuramo.javie.core.services.RenderContext;
-import ch.kuramo.javie.core.services.VideoRenderSupport;
 
 import com.google.inject.Inject;
 
@@ -48,7 +48,7 @@ public class AudioEffectPipelineImpl implements AudioEffectPipeline {
 	private RenderContext _context;
 
 	@Inject
-	private VideoRenderSupport _vrSupport;
+	private IVideoRenderSupport _vrSupport;
 
 	@Inject
 	private AudioRenderSupport _arSupport;
