@@ -52,13 +52,20 @@ public class BlurSupportImpl implements IBlurSupport {
 	}
 
 	private static final int[][] DOWNSAMPLE_RATIOS = {
-		{ 300, 7, 7 },
-		{ 200, 5, 7 },
-		{ 150, 5, 5 },
-		{ 100, 3, 5 },
-		{  50, 3, 3 },
-		{  30, 5 },
-		{  10, 3 }
+//		{ 500, 5, 5, 2 },	//  50
+		{ 400, 5, 4, 2 },	//  40
+		{ 300, 5, 3, 2 },	//  30
+		{ 250, 5, 5 },		//  25
+		{ 200, 5, 4 },		//  20
+		{ 150, 5, 3 },		//  15
+		{ 120, 4, 3 },		//  12
+		{ 100, 5, 2 },		//  10
+		{  80, 4, 2 },		//   8
+		{  60, 3, 2 },		//   6
+		{  40, 5 },			//   5
+		{  30, 4 },			//   4
+		{  20, 3 },			//   3
+		{  10, 2 }			//   2
 	};
 
 	private int[] getDownSampleRatios(double hint) {
@@ -77,6 +84,13 @@ public class BlurSupportImpl implements IBlurSupport {
 	private void doDownSample(
 			IVideoBuffer input, IVideoBuffer output, int hRatio, int vRatio) {
 
+		VideoBounds inputBounds = input.getBounds();
+		final VideoBounds outputBounds = output.getBounds();
+
+		double w = (double)outputBounds.width * hRatio / inputBounds.width;
+		double h = (double)outputBounds.height * vRatio / inputBounds.height;
+		final double[][] texCoords = new double[][] { {0, 0}, {w, 0}, {w, h}, {0, h} };
+
 		int ksize = hRatio * vRatio;
 		float[] kernel = new float[ksize];
 		float[] offset = new float[ksize*2];
@@ -85,21 +99,15 @@ public class BlurSupportImpl implements IBlurSupport {
 			for (int i = 0; i < hRatio; ++i) {
 				int k = j*hRatio+i;
 				kernel[k] = 1f/ksize;
-				offset[k*2  ] = i - hRatio/2;
-				offset[k*2+1] = j - vRatio/2;
+				offset[k*2  ] = (float)(i-hRatio*0.5+0.5) / inputBounds.width;
+				offset[k*2+1] = (float)(j-vRatio*0.5+0.5) / inputBounds.height;
 			}
 		}
 
-		final VideoBounds bounds = output.getBounds();
-		int w = bounds.width*hRatio;
-		int h = bounds.height*vRatio;
-
-		final double[][] texCoords = new double[][] { {0, 0}, {w, 0}, {w, h}, {0, h} };
-
 		Runnable operation = new Runnable() {
 			public void run() {
-				support.ortho2D(bounds);
-				support.quad2D(bounds, texCoords);
+				support.ortho2D(outputBounds);
+				support.quad2D(outputBounds, texCoords);
 			}
 		};
 
@@ -109,16 +117,17 @@ public class BlurSupportImpl implements IBlurSupport {
 	private void doUpSample(
 			IVideoBuffer input, IVideoBuffer output, int hRatio, int vRatio) {
 
-		final VideoBounds bounds = output.getBounds();
-		double w = (double)bounds.width/hRatio;
-		double h = (double)bounds.height/vRatio;
+		VideoBounds inputBounds = input.getBounds();
+		final VideoBounds outputBounds = output.getBounds();
 
+		double w = (double)outputBounds.width / hRatio / inputBounds.width;
+		double h = (double)outputBounds.height / vRatio / inputBounds.height;
 		final double[][] texCoords = new double[][] { {0, 0}, {w, 0}, {w, h}, {0, h} };
 
 		Runnable operation = new Runnable() {
 			public void run() {
-				support.ortho2D(bounds);
-				support.quad2D(bounds, texCoords);
+				support.ortho2D(outputBounds);
+				support.quad2D(outputBounds, texCoords);
 			}
 		};
 
