@@ -95,7 +95,15 @@ public class ShaderRegistryImpl implements ShaderRegistry, IShaderRegistry {
 						attach = new String[0];
 					}
 				}
-				entry = new ShaderEntry(name, sourceFactory.getType(), attach, sourceFactory.getSource());
+
+				String[] source = sourceFactory.getSource();
+				for (int i = 0; i < source.length; ++i) {
+					if (!source[i].endsWith("\n")) {
+						source[i] += "\n";
+					}
+				}
+
+				entry = new ShaderEntry(name, sourceFactory.getType(), attach, source);
 				try {
 					putEntry(name, entry);
 				} catch (ShaderRegistryException e) {
