@@ -25,12 +25,16 @@ package ch.kuramo.javie.core.internal.services;
 
 import java.util.List;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import ch.kuramo.javie.api.ICamera;
 import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.api.IVideoBuffer.TextureFilter;
 import ch.kuramo.javie.api.IVideoBuffer.TextureWrapMode;
 import ch.kuramo.javie.api.services.IVideoEffectContext;
+import ch.kuramo.javie.api.services.IVideoRenderSupport;
 import ch.kuramo.javie.core.Effect;
 import ch.kuramo.javie.core.Util;
 import ch.kuramo.javie.core.VideoEffect;
@@ -38,17 +42,19 @@ import ch.kuramo.javie.core.WrappedOperation;
 import ch.kuramo.javie.core.services.AudioRenderSupport;
 import ch.kuramo.javie.core.services.RenderContext;
 import ch.kuramo.javie.core.services.VideoEffectPipeline;
-import ch.kuramo.javie.core.services.VideoRenderSupport;
 
 import com.google.inject.Inject;
 
 public class VideoEffectPipelineImpl implements VideoEffectPipeline {
 
+	private static final Logger _logger = LoggerFactory.getLogger(VideoEffectPipelineImpl.class);
+
+
 	@Inject
 	private RenderContext _context;
 
 	@Inject
-	private VideoRenderSupport _vrSupport;
+	private IVideoRenderSupport _vrSupport;
 
 	@Inject
 	private AudioRenderSupport _arSupport;
@@ -157,27 +163,41 @@ public class VideoEffectPipelineImpl implements VideoEffectPipeline {
 					if (buffer == null) {
 						return doPreviousEffect();
 					}
-					// TODO エフェクトから返されたバッファのColorModeがコンテキストのColorModeと異なる場合、
-					//      コンテキストのColorModeのバッファにコピーして返す。また、警告をログに出す。
-					//      ただし、このコメントを書いた時点ではコンテキストのColorModeと異なるバッファを
-					//      エフェクト内で作成することはできない。
-					//if (buffer.getColorMode() != _context.getColorMode()) {
-					//	IVideoBuffer copy = _vrSupport.createVideoBuffer(_context.getColorMode(), buffer.getBounds());
-					//	_vrSupport.copy(buffer, copy);
-					//	buffer.dispose();
-					//	return copy;
-					//}
-					if (buffer.isTexture()) {
-						// TODO テクスチャの現在の補間モードとラッピングモードが NEAREST / CLAMP_TO_BORDER 以外の場合、警告をログに出す。
-						buffer.setTextureFilter(TextureFilter.NEAREST);
-						buffer.setTextureWrapMode(TextureWrapMode.CLAMP_TO_BORDER);
+
+					try {
+						if (buffer.getColorMode() != _context.getColorMode()) {
+							_logger.warn(String.format("ColorMode of the buffer from '%s' differs"
+											+ " from context ColorMode", currentEffect.getName()));
+
+							IVideoBuffer copy = null;
+							try {
+								copy = _vrSupport.createVideoBuffer(buffer.getBounds());
+								_vrSupport.copy(buffer, copy);
+								buffer.dispose();
+								buffer = copy;
+								copy = null;
+							} finally {
+								if (copy != null) copy.dispose();
+							}
+
+						} else if (buffer.isTexture()) {
+							// TODO テクスチャの現在の補間モードとラッピングモードが NEAREST / CLAMP_TO_BORDER 以外の場合、警告をログに出すべきか？
+							buffer.setTextureFilter(TextureFilter.NEAREST);
+							buffer.setTextureWrapMode(TextureWrapMode.CLAMP_TO_BORDER);
+						}
+
+						IVideoBuffer result = buffer;
+						buffer = null;
+						return result;
+
+					} finally {
+						if (buffer != null) buffer.dispose();
 					}
-					return buffer;
 				}
 			});
 		}
 
-		private <T> T executePrevious(final WrappedOperation<T> wop) {
+		private <T> T executePrevious(WrappedOperation<T> wop) {
 			VideoEffect savedCurrent = currentEffect;
 			List<VideoEffect> savedEffects = effects;
 			try {
@@ -186,11 +206,7 @@ public class VideoEffectPipelineImpl implements VideoEffectPipeline {
 				currentEffect = effects.get(lastIndex);
 				effects = effects.subList(0, lastIndex);
 
-				return _context.saveAndExecute(new WrappedOperation<T>() {
-					public T execute() {
-						return _vrSupport.pushMatrixAndExecute(wop);
-					}
-				});
+				return _context.saveAndExecute(wop);
 
 			} finally {
 				effects = savedEffects;
