@@ -25,12 +25,12 @@ package ch.kuramo.javie.core.services;
 
 import java.util.List;
 
-import ch.kuramo.javie.core.AudioBuffer;
+import ch.kuramo.javie.api.IAudioBuffer;
 import ch.kuramo.javie.core.Effect;
 import ch.kuramo.javie.core.WrappedOperation;
 
 public interface AudioEffectPipeline {
 
-	AudioBuffer doAudioEffects(List<Effect> effects, WrappedOperation<AudioBuffer> inputOperation);
+	IAudioBuffer doAudioEffects(List<Effect> effects, WrappedOperation<IAudioBuffer> inputOperation);
 
 }
