@@ -25,6 +25,8 @@ package ch.kuramo.javie.core.services;
 
 import org.mozilla.javascript.ContextFactory;
 
+import ch.kuramo.javie.api.services.IAccumulationSupport;
+import ch.kuramo.javie.api.services.IAlphaChannelSupport;
 import ch.kuramo.javie.api.services.IAntiAliasSupport;
 import ch.kuramo.javie.api.services.IArrayPools;
 import ch.kuramo.javie.api.services.IAudioEffectContext;
@@ -34,6 +36,8 @@ import ch.kuramo.javie.api.services.IConvolutionSupport;
 import ch.kuramo.javie.api.services.IShaderRegistry;
 import ch.kuramo.javie.api.services.IVideoEffectContext;
 import ch.kuramo.javie.api.services.IVideoRenderSupport;
+import ch.kuramo.javie.core.internal.services.AccumulationSupportImpl;
+import ch.kuramo.javie.core.internal.services.AlphaChannelSupportImpl;
 import ch.kuramo.javie.core.internal.services.AnimatableValueCollectorImpl;
 import ch.kuramo.javie.core.internal.services.AntiAliasSupportProxy;
 import ch.kuramo.javie.core.internal.services.ArrayPoolsImpl;
@@ -145,6 +149,14 @@ public class JavieCoreModule extends AbstractModule {
 				.to(BlurSupportImpl.class)
 				.in(Scopes.SINGLETON);
 
+		bind(IAlphaChannelSupport.class)
+				.to(AlphaChannelSupportImpl.class)
+				.in(Scopes.SINGLETON);
+
+		bind(IAccumulationSupport.class)
+				.to(AccumulationSupportImpl.class)
+				.in(Scopes.SINGLETON);
+
 		bind(FontList.class)
 				.to(FontListImpl.class)
 				.in(Scopes.SINGLETON);
