@@ -160,7 +160,7 @@ public class Circle {
 			invert = context.value(Circle.this.invert);
 			opacity = context.value(Circle.this.opacity) / 100;
 
-			Color color = context.value(Circle.this.color).clamp();
+			Color color = context.value(Circle.this.color);
 			double a = color.a;
 			this.color = new Color(color.r*a, color.g*a, color.b*a, a);
 
