@@ -108,9 +108,6 @@ public abstract class GradientBase {
 			throw new IllegalArgumentException("texSize must be greater than 0");
 		}
 
-		colorA = colorA.clamp();
-		colorB = colorB.clamp();
-
 		IArray<float[]> data = null;
 		try {
 			data = arrayPools.getFloatArray(texSize*4);
@@ -146,9 +143,6 @@ public abstract class GradientBase {
 			throw new IllegalArgumentException("texSize must be greater than 0");
 		}
 
-		colorA = colorA.clamp();
-		colorB = colorB.clamp();
-
 		IArray<float[]> data = null;
 		try {
 			data = arrayPools.getFloatArray(texSize*4);
