@@ -131,7 +131,7 @@ public class Grid {
 			invert = context.value(Grid.this.invert);
 			opacity = context.value(Grid.this.opacity) / 100;
 
-			Color color = context.value(Grid.this.color).clamp();
+			Color color = context.value(Grid.this.color);
 			double a = color.a;
 			this.color = new Color(color.r*a, color.g*a, color.b*a, a);
 
