@@ -157,7 +157,7 @@ public class Rectangle {
 			invert = context.value(Rectangle.this.invert);
 			opacity = context.value(Rectangle.this.opacity) / 100;
 
-			Color color = context.value(Rectangle.this.color).clamp();
+			Color color = context.value(Rectangle.this.color);
 			double a = color.a;
 			this.color = new Color(color.r*a, color.g*a, color.b*a, a);
 
