@@ -109,7 +109,7 @@ public class FractalNoise {
 		"	float t = sum * contrast + brightness;",
 		"",
 		"	if (overflow == 0) {",									// CLIP
-		"		t = min(max(0.5+0.5*t, 0.0), 1.0);",
+		"		t = clamp(0.5+0.5*t, 0.0, 1.0);",
 		"	} else if (overflow == 1) {",							// SOFT_CLAMP
 		"		t = 0.5+0.3183099*atan(t);",
 		"	} else if (overflow == 2) {",							// WRAP_BACK
@@ -428,8 +428,8 @@ public class FractalNoise {
 
 	private static String[] createHueOrSaturationBlendSource(boolean hue) {
 		return new String[] {
-				"uniform sampler2DRect texDst;",	// original
-				"uniform sampler2DRect texSrc;",	// noise
+				"uniform sampler2D texDst;",	// original
+				"uniform sampler2D texSrc;",	// noise
 				"uniform float opacity;",
 				"",
 				"const vec3 lumaVec = vec3(0.299, 0.587, 0.114);",
@@ -442,8 +442,8 @@ public class FractalNoise {
 				"void main(void)",
 				"{",
 				"	vec2 texCoord = gl_TexCoord[0].st;",
-				"	vec4 pDst = texture2DRect(texDst, texCoord);",
-				"	vec4 pSrc = texture2DRect(texSrc, texCoord);",
+				"	vec4 pDst = texture2D(texDst, texCoord);",
+				"	vec4 pSrc = texture2D(texSrc, texCoord);",
 				"",
 				"	float da = pDst.a;",
 				"	float sa = pSrc.a*opacity;",
